%%
clear all
close all
clc
%%

%Definizione parametri dinamici
T=1000; %Durata (s) del disturbo random
dt=0.01; %Passo di integrazione o ricostruzione della TH
t=(0:dt:T)'; %Vettore del tempo
df=0.01; %Passo di discertizzazione del vettore della frequenza
maxfreq=1/(2*dt); %Frequenza di Nyquist
freq=df:df:maxfreq; %Vettore della Frequenza
w=2*pi*freq;
fft_point=8192; %punti da utilizzare per l'analisi FFT

%Definizione PSD dell'ingresso
Sn=0*ones(length(freq),1);
for i=round(1):round(4/5*length(freq)),
    Sn(i)=10; %(units)^2/Hz
end
PSDu=Sn; %Disturbo PSD
% Estrazione dei momenti spettrali
[Mom_iff,Momif] = statPSD(freq,PSDu);    

rms_inf1 = sqrt(Mom_iff(1))
rms_inf2=sqrt(trapz(freq,PSDu))
% Np_i=sqrt(Mom_iff(5)/Mom_iff(3))
% N0p_i=sqrt(Mom_iff(3)/Mom_iff(1))
% gamma_i=Mom_iff(3)/sqrt(Mom_iff(1)*Mom_iff(5))

figure(1)
plot(freq,PSDu,'k','LineWidth',2)
hold on
str=['PSD INPUT - rms ',num2str(rms_inf1)];
title(str)
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
axis([0 maxfreq min(PSDu)/4 max(PSDu)*1.4])

%Ricostruzione del segnale di ingresso a partire dalla PSD di input
S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','..','date','..','L',400,'Bw',1.2535e+001);
% S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','..','date','..','L','..','Bw','..');
P2=T/dt;
itime=spec2sdat(S,P2,dt);
rms_int=std(itime(:,2));
[A,B]=spectrum(itime(:,2),fft_point,fft_point/4,hanning(fft_point));
rms_intf=sqrt(trapz(B(:,1)*maxfreq,A(:,1)/maxfreq));

figure(2)
plot(itime(:,1),itime(:,2),'b')
hold on
grid on
xlabel('time (s)')
ylabel('input (units)')
str=['TH INPUT - rms ',num2str(rms_int)];
title(str)

figure
hist(itime(:,2),100)
grid on
str=['Distribuzione processo - stddev and mean values ',num2str(mean(itime(:,2))),', ',num2str(std(itime(:,2)))];
title(str)
xlabel('Values (unit)')
ylabel('Occurrences')

% Estrazione della funzione di auto-correlazione
[xcorr_input,lags_input] = xcorr(itime(:,2),'none');

figure(4)
%stem(lags_input,xcorr_input,'r')
plot(lags_input,xcorr_input,'r')
hold on
grid on
ylabel('correlation function')
xlabel('units')
%axis([-2e3 2e3 -1.2 1.2])

figure(5)
plot(freq,PSDu,'k','LineWidth',2)
hold on
title('PSD INPUT')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
plot(B(:,1)*maxfreq,A(:,1)/maxfreq,'b')
axis([0 maxfreq min(PSDu)/4 max(PSDu)*1.4])
str=['PSD of TH and PSD INPUT - rms of TH PSD ',num2str(rms_intf)];
title(str)

%Definizione del Modellon 1dof
m=250; %Massa 1
csi=0.01; %Smorzamento 1
k=10000*4; %Rigidezza 1
w0=sqrt(k/m);
b=2*m*csi*w0; %Smorzamento 1

%State Space
A=[0 1; -w0^2 -b/m];
B=[0; 1/m];
C=[1*1e5 0];
D=0;
SYS=ss(A,B,C,D);
%Generazione della FRF
[mag,phase]=bode(SYS,w);

figure(6)
subplot(2,1,1)
loglog(freq,squeeze(mag(1,1,:)),'linewidth',1.5)
title('Mag(FRF) dof_2/dof_1')
ylabel('Displacement log(m)')
grid on
subplot(2,1,2)
semilogx(freq,squeeze(phase(1,1,:)),'linewidth',1.5)
title('Phase(FRF) dof_2/dof_1')
ylabel('Angle (angle)')
xlabel('freq (Hz)')
grid on

% %Simulazione nel tempo
output=lsim(SYS,itime(:,2),itime(:,1));
rms_r=std(output)

figure(7)
plot(itime(:,1),output,'r','LineWidth',0.5)
hold on
xlabel('TIME (s)')
ylabel('INPUT (unit)')
grid on
str=['TH RICOSTRUITA - rms ',num2str(rms_r)];
title(str)

figure
hist(output,100)
grid on
str=['Distribuzione processo - stddev and mean values ',num2str(mean(output)),', ',num2str(std(output))];
title(str)
xlabel('Values (unit)')
ylabel('Occurrences')

% Estrazione della funzione di auto-correlazione
[xcorr_ww,lags] = xcorr(output,'none');

figure(9)
%stem(lags,xcorr_ww,'r')
plot(lags,xcorr_ww,'r')
hold on
grid on
ylabel('correlation function')
xlabel('units')
%axis([-2e3 2e3 -1.2 1.2])

% Analisi del contenuto in frequenza (PSD) del segnale temporale di output
[A1,B1]=spectrum(output,fft_point,fft_point/4,hanning(fft_point));

% Analisi dinamica in frequenza (PSD)
MAG=squeeze(mag(1,1,:));
PSDoutput=PSDu.*MAG.^2;

freqtf=B1(:,1)*maxfreq;
PSDouttf=A1(:,1)/maxfreq;
freqf=freq;
PSDoutf=PSDoutput;
% Estrazione dei momenti spettrali
[Mom_ftf,Momtf] = statPSD(freqtf,PSDouttf);    
[Mom_ff,Momf] = statPSD(freqf,PSDoutf);    

rms_f1 = sqrt(Mom_ftf(1))
rms_f2 = sqrt(Mom_ff(1))
Np_f1=sqrt(Mom_ftf(5)/Mom_ftf(3))
N0p_f1=sqrt(Mom_ftf(3)/Mom_ftf(1))
gamma_f1=Mom_ftf(3)/sqrt(Mom_ftf(1)*Mom_ftf(5))
Np_f2=sqrt(Mom_ff(5)/Mom_ff(3))
N0p_f2=sqrt(Mom_ff(3)/Mom_ff(1))
gamma_f2=Mom_ff(3)/sqrt(Mom_ff(1)*Mom_ff(5))

figure(10)
loglog(freqf,PSDoutf,'b','linewidth',2)
hold on
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
loglog(freqtf,PSDouttf,'r','linewidth',2)
axis([0.1 maxfreq min(PSDouttf) max(PSDouttf)*2])
str=['PSD of output TH vs output PSD - rms of both ',num2str(rms_f1),', ',num2str(rms_f2)];
title(str)

%%

Nk=100;
T=1000; %Durata (s) del processo random
P_test=T/dt;
S_test = struct('S',(1)/(2*pi)*PSDouttf,'w',2*pi*freqtf','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','..','date','..','L',400,'Bw',1.2535e+001);
% S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','..','date','..','L','..','Bw','..');
for i=1:Nk,
    itime=spec2sdat(S_test,P_test,dt);
    ITIME(:,1:2,i)=itime;
end

x=[min(min(ITIME(:,2,:))):10:max(max(ITIME(:,2,:)))];

jj=0;
Nt=100;
Delta=P_test/Nt;
for i=1:Delta:P_test,
    jj=jj+1;
    STDt(jj)=std(ITIME(i,2,:));
    MEANt(jj)=mean(ITIME(i,2,:));
    HISTt(jj,:)=hist(ITIME(i,2,:),x);
end
for i=1:Nk,
    STDk(i)=std(ITIME(:,2,i));
    MEANk(i)=mean(ITIME(:,2,i));
    HISTk(i,:)=hist(ITIME(:,2,i),x);
end

%%

figure
bar3(HISTk)

figure
bar3(HISTt)



