clear all
close all
clc

%Definizione parametri dinamici
T=10000; %Durata (s) del disturbo random
dt=0.01; %Passo di integrazione o ricostruzione della TH
t=(0:dt:T)'; %Vettore del tempo
df=0.1; %Passo di discertizzazione del vettore della frequenza
maxfreq=1/(2*dt); %Frequenza di Nyquist
freq=df:df:maxfreq; %Vettore della Frequenza
w=2*pi*freq;
fft_point=2048; %punti da utilizzare per l'analisi FFT

%Definizione PSD dell'ingresso
Sn=0*ones(length(freq),1);
for i=1:length(freq),
    Sn(i)=1e-8; %(units)^2/Hz
end
PSDu=Sn; %Disturbo PSD

%Ricostruzione del segnale di ingresso a partire dalla PSD di input
S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','...','date','..','L',400,'Bw',1.2535e+001);
% S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','..','date','..','L','..','Bw','..');
P2=T/dt;
itime=spec2sdat(S,P2,dt);
[A,B]=spectrum(itime(:,2),fft_point,fft_point/4,hanning(fft_point));

figure(1)
plot(itime(:,1),itime(:,2))
hold on
grid on
xlabel('time (s)')
ylabel('input (units)')

figure(2)
loglog(freq,PSDu,'k','LineWidth',2)
hold on
title('PSD INPUT')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
loglog(B(:,1)*maxfreq,A(:,1)/maxfreq,'r')
axis([0.5 maxfreq min(PSDu)/1.2 max(PSDu)*1.2])

%Definizione del Modellon 2dof
m1 = 125;
k1 = 50000;
c1 = 15; 
m2 = 15;
k2 = 50000;
c2 = 150;

%State Space
A=[ 0       0             1       0
    0       0             0       1
    -k1/m1 k1/m1        -c1/m1 c1/m1
    k1/m2  -(k1+k2)/m2 c1/m2  -(c1+c2)/m2];
B=[ 0
     c2/m2
     c1*c2/(m1*m2)
     k2/m2-(c1+c2)*c2/(m2^2)];
C=2e2*[ 1       0             0       0
    0       1             0       0
    0       0             1       0
    0       0             0       1
    -k1/m1 k1/m1        -c1/m1 c1/m1];      % in spostamento
D=[ 0 0 0 c2/m2 c1*c2/(m1*m2)]';         % in spostamento
SYS=ss(A,B,C,D);

input=1;
output=5;
%Generazione della FRF
[mag,phase]=bode(SYS,w);

figure(3)
subplot(2,1,1)
loglog(freq,squeeze(mag(output,input,:)),'linewidth',1.5)
title('Mag(FRF) dof_2/dof_1')
ylabel('Displacement log(m)')
subplot(2,1,2)
semilogx(freq,squeeze(phase(output,input,:)),'linewidth',1.5)
title('Phase(FRF) dof_2/dof_1')
ylabel('Angle (angle)')
xlabel('freq (Hz)')

% %Simulazione nel tempo
outpu=lsim(SYS,itime(:,2),itime(:,1));
outpu=outpu(:,output);
rms_r=std(outpu);

% Analisi in frequenza (PSD) del segnale temporale
[A1,B1]=spectrum(outpu,fft_point,fft_point/4,hanning(fft_point));

figure(4)
plot(itime(:,1),outpu,'r','LineWidth',0.5)
hold on
title('TH RICOSTRUITA')
xlabel('TIME (s)')
ylabel('INPUT (unit)')
grid on

figure(5)
loglog(B1(:,1)*maxfreq,A1(:,1)/maxfreq,'r','linewidth',2)
hold on
title('PSD OUTPUT')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
axis([0.5 maxfreq min(A1(:,1)/maxfreq) max(A1(:,1)/maxfreq)*1.2])

% Estrazione della funzione di auto-correlazione
[c_ww,lags] = xcorr(outpu,'coeff');

figure(6)
%stem(lags,c_ww)
plot(lags,c_ww)
hold on
grid on
ylabel('autocorrelation function')
xlabel('units')
axis([-2e3 2e3 -1.2 1.2])

freq=B1(:,1)*maxfreq;
PSDout=A1(:,1)/maxfreq;
% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik
deltasigma=30;
[pdf_d,Mom_d] = dirlik(freq,PSDout,deltasigma);    
[pdf_b,Mom_b] = rayleigh(freq,PSDout,deltasigma);    
N_d=deltasigma/2*sqrt(Mom_d(5)/Mom_d(3));
N_b=deltasigma/2*sqrt(Mom_b(5)/Mom_b(3));
rms_d = sqrt(Mom_d(1));
rms_b = sqrt(Mom_b(1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Estrazione dello spettro dei cicli mediante conteggio rainflow nel dominio
%del tempo
signal=[itime(:,1) outpu];
P3D=0; %RainFlow Matrix plot 2dimensional
RES=1; %Residuals (Cloormann/Seeger) 
fil=0;
num=100;
plotid=0;
[tp,rfc,spettro,res] = conteggio(signal,fil,num,RES,P3D,plotid);
% spettro=rfc;
spettro=[spettro(:,1) spettro(:,3)];
N_r=sum(spettro(:,1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Ricostruzione pdf sperimentale
plotid=0;
[x_r, y_r]=plotta_pdf(spettro,num,3,'r',plotid);
pdf_r(:,2)=x_r;
pdf_r(:,1)=y_r;
 
%Plottaggio pdf
figure(7)
plot(pdf_r(:,2),pdf_r(:,1),'r','linewidth',2)
hold on
plot(pdf_d(:,2),pdf_d(:,1),'k','linewidth',2)
plot(pdf_b(:,2),pdf_b(:,1),'b','linewidth',2)
hold on
grid on
ylabel('Pdf')
xlabel('units')
title('Pdf di carico')
legend('Dirlik','Bendat','Sperimentale')

spe_d = cumula([pdf_d(:,1)*T*N_b pdf_d(:,2)],'k',0,100);
spe_b = cumula([pdf_b(:,1)*T*N_b pdf_b(:,2)],'b',0,100);
spe_r = cumula(spettro,'r',0,100);
pp=axis;
axis([1 max(spe_r(:,1))*2 0 max(spe_r(:,2))*1.2])
legend('Dirlik','Bendat','Sperimentale')
