clc
clear all
close all

%%

%Parametri

%Forze esterne
F=20000;
Cf=0.10;
sf=F*Cf;

%Momento torcente
Mt=1000;
Cmt=0.10;
smt=Mt*Cmt;

%Materiale
gammay=1.2;

HB=150e6;
Chb=0.02;
shb=HB*Chb;

Sut=3.45*HB;
Csut=((0.044^2+Chb^2)^(1/2));
ssut=Sut*Csut;

Sy=Sut/gammay;
Csy=Csut;
ssy=Sy*Csy;

Suc=3*Sut;
Csuc=1.3*Csut;
ssuc=Suc*Csuc;

%Geometria sezione
d=0.04;
Cd=0.005;
sd=d*Cd;

A=pi*d^2/4;
sa=pi/2*Cd*d^2;
Ca=sa/A;

W=pi*d^3/32;
sw=3*Cd*pi*d^3/32;
Cw=sw/W;

Wt=pi*d^3/16;
swt=3*Cd*pi*d^3/16;
Cwt=swt/Wt;

%Geometria struttura
a=0.10;
l=0.50;

%Reazioni vincolari
Ra=F*a/l;
Rb=F*(l+a)/l;
Cra=Cf;
Crb=Cf;
sra=Ra*Cra;
srb=Rb*Crb;

%Momento flettente
Mf=F*a;
Cmf=Cf;
smf=Mf*Cmf;

%Taglio
T=F;
Ct=Cf;
st=T*Ct;

%Tensione normale 1
sigma_x=Mf/W;
Csigma_x=(Cmf^2+Cw^2)^(1/2);
ssigma_x=sigma_x*Csigma_x;

%Tensione normale 2
sigma_y=0;
Csigma_y=0;
ssigma_y=sigma_y*Csigma_y;

%Tensione tangenziale (Momento torcente)
tau_xy_1=Mt/Wt;
Ctau_xy_1=(Cmt^2+Cwt^2)^(1/2);
stau_xy_1=tau_xy_1*Ctau_xy_1;

%Tensione tangenziale (Taglio)
tau_xy_2=4/3*T/A;
Ctau_xy_2=(Ct^2+Ca^2)^(1/2);
stau_xy_2=tau_xy_2*Ctau_xy_2;

%Tensione tangenziale
tau_xy=tau_xy_1+tau_xy_2;
stau_xy=(stau_xy_1^2+stau_xy_2^2)^(1/2);
Ctau_xy=stau_xy/tau_xy;

%Tensioni principali
[sigma1,ssigma1,sigma2,ssigma2]=sprinc(tau_xy,stau_xy,sigma_x,ssigma_x,sigma_y,ssigma_y)
Csigma1=ssigma1/sigma1;
Csigma2=ssigma2/abs(sigma2);

%Tresca
[sidt,ssidt]=stresca(sigma1,ssigma1,sigma2,ssigma2)
Csidt=ssidt/sidt;
% [sidt2,ssidt2]=stresca2(sigma_x,Csigma_x,tau_xy,Ctau_xy)
% Csidt2=ssidt2/sidt2;

%von Mises
[sidvm,ssidvm]=svonmises(sigma_x,Csigma_x,tau_xy,Ctau_xy)
Csidvm=ssidvm/sidvm;

sid=sidt;
ssid=ssidt;
Csid=Csidt;

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Analisi dell'affidabilit
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Xvalues=[0:5:1000]*1e6;

npdfS=normpdf(Xvalues,Sy,ssy);
npdfs=normpdf(Xvalues,sid,ssid);
npdfz=normpdf(Xvalues,(Sy-sid),(sqrt(ssid^2+ssy^2)));
for i=1:length(Xvalues),
    npdfsS(i,:)=npdfS(i)*npdfs;
end

n_medio=Sy/sid

% z=(sid-Sy)/ssy;
% P=normcdf(z,0,1);
% R=1-P
% 
% n=1/(Csy*z+1)

% Rkl=0.05;
% Pkl=1-Rkl;
Pkl=0.95;
zkl=norminv(Pkl,0,1)

sidkl=ssid*(zkl)+sid;
z=(sidkl-Sy)/ssy
P=normcdf(z,0,1);
R=1-P

n=1/(Csy*z+1)

Rkm=0.95;
Pkm=1-Rkm;
zkm=norminv(Pkm,0,1);

Sykm=ssy*(zkm)+Sy;
z=(Sykm-sid)/ssid;
P=normcdf(z,0,1)

n=1/(1/(Csid*z+1))

n_min=Sykm/sidkl

[z,R]=eqacc_norm(Sy,ssy,sid,ssid)

if R>=0.5
    a=1;
else
    a=-1;
end

n=(1+(a)*sqrt(1-(1-z^2*Csy^2)*(1-z^2*Csid^2)))/(1-z^2*Csy^2)

Rext=0.999;
Pext=1-Rext;
zext=norminv(Pext,0,1);

R=Rext;
z=zext;

if R>=0.5
    a=1;
else
    a=-1;
end

n=(1+(a)*sqrt(1-(1-z^2*Csy^2)*(1-z^2*Csid^2)))/(1-z^2*Csy^2)

%Resistenza
muS=Sy; devS=ssy;
%Sollecitazione
mus=sid; devs=ssid;

ProbabilityS=0.05;
Probabilitys=0.95;

Sk_P=norminv(ProbabilityS,muS,devS);
sk_P=norminv(Probabilitys,mus,devs);
S_p=normpdf(Sk_P,muS,devS);
s_p=normpdf(sk_P,mus,devs);

gammakS=muS/Sk_P
gammaks=sk_P/mus
CoeffSick=gammaks*gammakS;

gammaS=1.1;
gammas=1.2;
Sd=muS/gammaS;
sd=mus*gammas;
CoeffSicd=gammas*gammaS;

figid=0;

gamma=1;
[fxy,FXY,pM,PM,FM]=joint_distribution(mus,devs,muS,devS,Xvalues,gamma,figid);
PM
gamma=Sk_P/sk_P;
[fxy,FXY,pMk,PMk,FMk]=joint_distribution(mus,devs,muS,devS,Xvalues,gamma,figid);
PMk
gamma=Sd/sd;
[fxy,FXY,pMd,PMd,FMd]=joint_distribution(mus,devs,muS,devS,Xvalues,gamma,figid);
PMd

%%

% figure(1)
% surf(Xvalues,Xvalues,npdfsS)
% hold on
% xlabel('Sollecitazione (s) [stress units]')
% ylabel('Resistenza (S) [stress units]')
% zlabel('f(x) PDF')
% title('Funzione di densit di Probabilit Congiunta')
% plot3(Xvalues,ones(length(Xvalues),1)*0,npdfs*(max(max(npdfsS))/max(npdfs)),'k')
% plot3(ones(length(Xvalues),1)*0,Xvalues,npdfS*(max(max(npdfsS))/max(npdfS)),'k')
% plot3(diag(Xvalues),diag(Xvalues),ones(length(Xvalues),1)*0,'w','linewidth',2)
% 
% plot3(diag(Xvalues)*sd,diag(Xvalues)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',2)
% hold on
% plot3(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',2)
% % plot3(0,S_P,S_p*(max(max(npdfsS))/max(npdfS)),'ro','linewidth',2)
% % plot3(s_P,0,s_p*(max(max(npdfsS))/max(npdfs)),'bo','linewidth',2)
% plot3(ones(length(Xvalues),1)*sk_P,Xvalues,ones(length(Xvalues),1)*0,'b','linewidth',1)
% plot3(Xvalues,ones(length(Xvalues),1)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',1)
% plot3(ones(length(Xvalues),1)*sd,Xvalues,ones(length(Xvalues),1)*0,'r','linewidth',1)
% plot3(Xvalues,ones(length(Xvalues),1)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',1)
% S=axis;
% axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end) S(5) S(6)])
% 
% figure(2)
% contour3(Xvalues,Xvalues,npdfsS,50)
% hold on
% xlabel('Sollecitazione (s) [stress units]')
% ylabel('Resistenza (S) [stress units]')
% zlabel('f(x) PDF')
% title('Funzione di densit di Probabilit Congiunta')
% plot3(Xvalues,ones(length(Xvalues),1)*0,npdfs*(max(max(npdfsS))/max(npdfs)),'k')
% plot3(ones(length(Xvalues),1)*0,Xvalues,npdfS*(max(max(npdfsS))/max(npdfS)),'k')
% plot3(diag(Xvalues),diag(Xvalues),ones(length(Xvalues),1)*0,'k','linewidth',2)
% 
% plot3(diag(Xvalues)*sd,diag(Xvalues)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',2)
% hold on
% plot3(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',2)
% % plot3(0,S_P,S_p*(max(max(npdfsS))/max(npdfS)),'ro','linewidth',2)
% % plot3(s_P,0,s_p*(max(max(npdfsS))/max(npdfs)),'bo','linewidth',2)
% plot3(ones(length(Xvalues),1)*sk_P,Xvalues,ones(length(Xvalues),1)*0,'b','linewidth',1)
% plot3(Xvalues,ones(length(Xvalues),1)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',1)
% plot3(ones(length(Xvalues),1)*sd,Xvalues,ones(length(Xvalues),1)*0,'r','linewidth',1)
% plot3(Xvalues,ones(length(Xvalues),1)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',1)
% S=axis;
% axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end) S(5) S(6)])
% 
% p=normspec([-inf 0],(muS-mus),(sqrt(devS^2+devs^2)));
% hold on
% plot(Xvalues,npdfS,'g','linewidth',2)
% plot(Xvalues,npdfs,'r','linewidth',2)
% plot(Xvalues,npdfz,'b','linewidth',2)
% grid on
% xlabel('Sollecitazione/Resistenza [stress units]')
% ylabel('f(x) PDF')
% str = ['Probability Between Limits is ',num2str(p)];
% title(str)
% 
% figure(4)
% subplot(2,2,2); contour3(Xvalues,Xvalues,npdfsS,50) ;axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)]); h1 = gca;
% title('Simulated Dependent Sigma and Strength Values');
% xlabel('X1 ~ Sigma'); ylabel('X2 ~ Strength');
% hold on
% plot(Xvalues,Xvalues,'k','linewidth',2)
% plot(diag(Xvalues)*sd,diag(Xvalues)*Sd,'r','linewidth',2)
% plot(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,'b','linewidth',2)
% plot(ones(length(Xvalues),1)*sk_P,Xvalues,'b','linewidth',1)
% plot(Xvalues,ones(length(Xvalues),1)*Sk_P,'b','linewidth',1)
% plot(ones(length(Xvalues),1)*sd,Xvalues,'r','linewidth',1)
% plot(Xvalues,ones(length(Xvalues),1)*Sd,'r','linewidth',1)
% S=axis;
% axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)])
% subplot(2,2,4); plot(Xvalues,-npdfs); axis([Xvalues(1) Xvalues(end) -max(npdfs)*1.1 0]); grid on; h2 = gca;
% subplot(2,2,1); plot(-npdfS,Xvalues); axis([-max(npdfS)*1.1 0 Xvalues(1) Xvalues(end)]); grid on; h3 = gca; 
% set(h1,'Position',[0.35 0.35 0.55 0.55]);
% set(h2,'Position',[.35 .1 .55 .15]);
% set(h3,'Position',[.1 .35 .15 .55]);
% 
% figure(5)
% surf(Xvalues,Xvalues,pMk)
% hold on
% xlabel('Sollecitazione (s) [stress units]')
% ylabel('Resistenza (S) [stress units]')
% zlabel('f(x) PDF')
% title('Funzione di densit di Probabilit Congiunta')
% plot3(Xvalues,ones(length(Xvalues),1)*0,npdfs*(max(max(npdfsS))/max(npdfs)),'k')
% plot3(ones(length(Xvalues),1)*0,Xvalues,npdfS*(max(max(npdfsS))/max(npdfS)),'k')
% plot3(diag(Xvalues),diag(Xvalues),ones(length(Xvalues),1)*0,'k','linewidth',2)
% plot3(diag(Xvalues)*sd,diag(Xvalues)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',2)
% hold on
% plot3(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',2)
% % plot3(0,S_P,S_p*(max(max(npdfsS))/max(npdfS)),'ro','linewidth',2)
% % plot3(s_P,0,s_p*(max(max(npdfsS))/max(npdfs)),'bo','linewidth',2)
% plot3(ones(length(Xvalues),1)*sk_P,Xvalues,ones(length(Xvalues),1)*0,'b','linewidth',1)
% plot3(Xvalues,ones(length(Xvalues),1)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',1)
% plot3(ones(length(Xvalues),1)*sd,Xvalues,ones(length(Xvalues),1)*0,'r','linewidth',1)
% plot3(Xvalues,ones(length(Xvalues),1)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',1)
% S=axis;
% axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end) S(5) S(6)])
% 
% figure(6)
% subplot(2,2,2); contour3(Xvalues,Xvalues,pMd,50) ;axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)]); h1 = gca;
% title('Simulated Dependent Sigma and Strength Values');
% xlabel('X1 ~ Sigma'); ylabel('X2 ~ Strength');
% hold on
% plot(Xvalues,Xvalues,'k','linewidth',2)
% plot(diag(Xvalues)*sd,diag(Xvalues)*Sd,'r','linewidth',2)
% plot(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,'b','linewidth',2)
% plot(ones(length(Xvalues),1)*sk_P,Xvalues,'b','linewidth',1)
% plot(Xvalues,ones(length(Xvalues),1)*Sk_P,'b','linewidth',1)
% plot(ones(length(Xvalues),1)*sd,Xvalues,'r','linewidth',1)
% plot(Xvalues,ones(length(Xvalues),1)*Sd,'r','linewidth',1)
% S=axis;
% axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)])
% subplot(2,2,4); plot(Xvalues,-npdfs); axis([Xvalues(1) Xvalues(end) -max(npdfs)*1.1 0]); grid on; h2 = gca;
% subplot(2,2,1); plot(-npdfS,Xvalues); axis([-max(npdfS)*1.1 0 Xvalues(1) Xvalues(end)]); grid on; h3 = gca; 
% set(h1,'Position',[0.35 0.35 0.55 0.55]);
% set(h2,'Position',[.35 .1 .55 .15]);
% set(h3,'Position',[.1 .35 .15 .55]);
% 
% figure(7)
% subplot(2,2,2); contour3(Xvalues,Xvalues,pM,50) ;axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)]); h1 = gca;
% title('Simulated Dependent Sigma and Strength Values');
% xlabel('X1 ~ Sigma'); ylabel('X2 ~ Strength');
% hold on
% plot(Xvalues,Xvalues,'k','linewidth',2)
% S=axis;
% axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)])
% subplot(2,2,4); plot(Xvalues,-npdfs); axis([Xvalues(1) Xvalues(end) -max(npdfs)*1.1 0]); grid on; h2 = gca;
% subplot(2,2,1); plot(-npdfS,Xvalues); axis([-max(npdfS)*1.1 0 Xvalues(1) Xvalues(end)]); grid on; h3 = gca; 
% set(h1,'Position',[0.35 0.35 0.55 0.55]);
% set(h2,'Position',[.35 .1 .55 .15]);
% set(h3,'Position',[.1 .35 .15 .55]);

%%

Sut;
Csut;
ssut;
Suc=-Suc;
Csuc;
ssuc;

sigma1;
sigma2;
Csigma1;
Csigma2;
%ssigmap=ssigma1=ssigma2;

r=sigma1/sigma2;

n_cm=(Sut*Suc)/(sigma1*Suc+sigma2*Sut)

S1=n_cm*sigma1;
S2=S1/r;
% S2=n_cm*sigma2
t1=sqrt(S2^2+(Sut-S1)^2)/sqrt(Suc^2+Sut^2);
t2=sqrt(S1^2+(Suc-S2)^2)/sqrt(Suc^2+Sut^2);
Cs1=+(abs(Csuc-Csut)*t1)+Csut;
Cs2=-(abs(Csuc-Csut)*t2)+Csuc;
ss1=Cs1*abs(S1);
ss2=Cs2*abs(S2);

%%%
%%% Approccio cautelativo (Verifica ed Affidabilit pag. 12)
%%%
% ss=sqrt(ssigma1^2+ssigma2^2)
% sS=sqrt(ss1^2+ss2^2)
%%%
%%% Approccio cautelativo (Verifica ed Affidabilit pag. 12)
%%%

%%%
%%% Approccio consigliato (Verifica ed Affidabilit pag. 13)
%%%
teta=asin(1/r);
ss=sqrt((ssigma1*cos(teta))^2+(ssigma2*sin(teta))^2);
sS=sqrt((ss1*cos(teta))^2+(ss2*sin(teta))^2);

s=sqrt(sigma1^2+sigma2^2)
S=sqrt(S1^2+S2^2)
%%%
%%% Approccio consigliato (Verifica ed Affidabilit pag. 13)
%%%

%%

Xvalues=[0:10:1000]*1e6;

clear  npdfS npdfs npdfsS

npdfS=normpdf(Xvalues,S,sS);
npdfs=normpdf(Xvalues,s,ss);
npdfz=normpdf(Xvalues,(S-s),(sqrt(ss^2+sS^2)));
for i=1:length(Xvalues),
    npdfsS(i,:)=npdfS(i)*npdfs;
end

[z,R]=eqacc_norm(S,sS,s,ss)

p=normspec([-inf 0],(S-s),(sqrt(ss^2+sS^2)));
hold on
plot(Xvalues,npdfS,'k','linewidth',2)
plot(Xvalues,npdfs,'r','linewidth',2)
plot(Xvalues,npdfz,'b','linewidth',2)
grid on
xlabel('Sollecitazione/Resistenza [stress units]')
ylabel('f(x) PDF')
str = ['Probability S vs s Between Limits is ',num2str(p)];
title(str)

Pkm=0.99;
zk=norminv(Pkm,0,1)
Sutkm_p=ssut*(zk)+Sut;
Sutkm_m=ssut*(-zk)+Sut;
Suckm_p=ssuc*(zk)+(-Suc);
Suckm_m=ssuc*(-zk)+(-Suc);

sigma1p=ss*(zk)+s;
sigma1m=ss*(-zk)+s;

figure
plot([Sut 0 Suc Suc 0 Sut Sut],[0 Suc Suc 0 Sut Sut 0],'k','linewidth',2)
hold on
grid
axis equal
plot([Sutkm_p 0 -Suckm_p -Suckm_p 0 Sutkm_p Sutkm_p],[0 -Suckm_p -Suckm_p 0 Sutkm_p Sutkm_p 0],'k','linewidth',1)
plot([Sutkm_m 0 -Suckm_m -Suckm_m 0 Sutkm_m Sutkm_m],[0 -Suckm_m -Suckm_m 0 Sutkm_m Sutkm_m 0],'k','linewidth',1)
plot(sigma1,sigma2,'or','linewidth',2)
plot([0:10:600]*1e6,sigma2/sigma1*[0:10:600]*1e6,'k','linewidth',1)
plot(sigma1p,sigma2/sigma1*sigma1p,'or','linewidth',2)
plot(sigma1m,sigma2/sigma1*sigma1m,'or','linewidth',2)


%%%
%%% Approccio semierrato (Verifica ed Affidabilit pag. 11)
%%%
% npdfS1=normpdf(Xvalues,S1,ss1);
% npdfS2=normpdf(Xvalues,-S2,ss2);
% npdfs1=normpdf(Xvalues,sigma1,ssigma1);
% npdfs2=normpdf(Xvalues,-sigma2,ssigma2);
% npdfz1=normpdf(Xvalues,(S1-sigma1),(sqrt(ss1^2+ssigma1^2)));
% npdfz2=normpdf(Xvalues,-(S2-sigma2),(sqrt(ss2^2+ssigma2^2)));
% [z1,R1]=eqacc_norm(S1,ss1,sigma1,ssigma1)
% [z2,R2]=eqacc_norm(-S2,ss2,-sigma2,ssigma2)
% 
% p1=normspec([-inf 0],(S1-sigma1),(sqrt(ss1^2+ssigma1^2)));
% hold on
% plot(Xvalues,npdfS1,'k','linewidth',2)
% plot(Xvalues,npdfs1,'r','linewidth',2)
% plot(Xvalues,npdfz1,'b','linewidth',2)
% grid on
% xlabel('Sollecitazione/Resistenza [stress units]')
% ylabel('f(x) PDF')
% str = ['Probability S1 vs s1 Between Limits is ',num2str(p1)];
% title(str)
% 
% p2=normspec([-inf 0],-(S2-sigma2),(sqrt(ss2^2+ssigma2^2)));
% hold on
% plot(Xvalues,npdfS2,'k','linewidth',2)
% plot(Xvalues,npdfs2,'r','linewidth',2)
% plot(Xvalues,npdfz2,'b','linewidth',2)
% grid on
% xlabel('Sollecitazione/Resistenza [stress units]')
% ylabel('f(x) PDF')
% str = ['Probability S2 vs s2 Between Limits is ',num2str(p2)];
% title(str)
%%%
%%% Approccio semierrato (Verifica ed Affidabilit pag. 11)
%%%


%Resistenza
muS=S; devS=sS;
%Sollecitazione
mus=s; devs=ss;

ProbabilityS=0.05;
Probabilitys=0.95;

Sk_P=norminv(ProbabilityS,muS,devS);
sk_P=norminv(Probabilitys,mus,devs);
S_p=normpdf(Sk_P,muS,devS);
s_p=normpdf(sk_P,mus,devs);

gammakS=muS/Sk_P
gammaks=sk_P/mus
CoeffSick=gammaks*gammakS;

gammaS=1.1;
gammas=1.2;
Sd=muS/gammaS;
sd=mus*gammas;
CoeffSicd=gammas*gammaS;

figid=0;

gamma=1;
[fxy,FXY,pM,PM,FM]=joint_distribution(mus,devs,muS,devS,Xvalues,gamma,figid);
PM
gamma=Sk_P/sk_P;
[fxy,FXY,pMk,PMk,FMk]=joint_distribution(mus,devs,muS,devS,Xvalues,gamma,figid);
PMk
gamma=Sd/sd;
[fxy,FXY,pMd,PMd,FMd]=joint_distribution(mus,devs,muS,devS,Xvalues,gamma,figid);
PMd

%%

figure
surf(Xvalues,Xvalues,npdfsS)
hold on
xlabel('Sollecitazione (s) [stress units]')
ylabel('Resistenza (S) [stress units]')
zlabel('f(x) PDF')
title('Funzione di densit di Probabilit Congiunta')
plot3(Xvalues,ones(length(Xvalues),1)*0,npdfs*(max(max(npdfsS))/max(npdfs)),'k')
plot3(ones(length(Xvalues),1)*0,Xvalues,npdfS*(max(max(npdfsS))/max(npdfS)),'k')
plot3(diag(Xvalues),diag(Xvalues),ones(length(Xvalues),1)*0,'w','linewidth',2)

plot3(diag(Xvalues)*sd,diag(Xvalues)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',2)
hold on
plot3(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',2)
% plot3(0,S_P,S_p*(max(max(npdfsS))/max(npdfS)),'ro','linewidth',2)
% plot3(s_P,0,s_p*(max(max(npdfsS))/max(npdfs)),'bo','linewidth',2)
plot3(ones(length(Xvalues),1)*sk_P,Xvalues,ones(length(Xvalues),1)*0,'b','linewidth',1)
plot3(Xvalues,ones(length(Xvalues),1)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',1)
plot3(ones(length(Xvalues),1)*sd,Xvalues,ones(length(Xvalues),1)*0,'r','linewidth',1)
plot3(Xvalues,ones(length(Xvalues),1)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',1)
Ax=axis;
axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end) Ax(5) Ax(6)])

figure
contour3(Xvalues,Xvalues,npdfsS,50)
hold on
xlabel('Sollecitazione (s) [stress units]')
ylabel('Resistenza (S) [stress units]')
zlabel('f(x) PDF')
title('Funzione di densit di Probabilit Congiunta')
plot3(Xvalues,ones(length(Xvalues),1)*0,npdfs*(max(max(npdfsS))/max(npdfs)),'k')
plot3(ones(length(Xvalues),1)*0,Xvalues,npdfS*(max(max(npdfsS))/max(npdfS)),'k')
plot3(diag(Xvalues),diag(Xvalues),ones(length(Xvalues),1)*0,'k','linewidth',2)

plot3(diag(Xvalues)*sd,diag(Xvalues)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',2)
hold on
plot3(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',2)
% plot3(0,S_P,S_p*(max(max(npdfsS))/max(npdfS)),'ro','linewidth',2)
% plot3(s_P,0,s_p*(max(max(npdfsS))/max(npdfs)),'bo','linewidth',2)
plot3(ones(length(Xvalues),1)*sk_P,Xvalues,ones(length(Xvalues),1)*0,'b','linewidth',1)
plot3(Xvalues,ones(length(Xvalues),1)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',1)
plot3(ones(length(Xvalues),1)*sd,Xvalues,ones(length(Xvalues),1)*0,'r','linewidth',1)
plot3(Xvalues,ones(length(Xvalues),1)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',1)
Ax=axis;
axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end) Ax(5) Ax(6)])

p=normspec([-inf 0],(muS-mus),(sqrt(devS^2+devs^2)));
hold on
plot(Xvalues,npdfS,'g','linewidth',2)
plot(Xvalues,npdfs,'r','linewidth',2)
plot(Xvalues,npdfz,'b','linewidth',2)
grid on
xlabel('Sollecitazione/Resistenza [stress units]')
ylabel('f(x) PDF')
str = ['Probability Between Limits is ',num2str(p)];
title(str)

figure
subplot(2,2,2); contour3(Xvalues,Xvalues,npdfsS,50) ;axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)]); h1 = gca;
title('Simulated Dependent Sigma and Strength Values');
xlabel('X1 ~ Sigma'); ylabel('X2 ~ Strength');
hold on
plot(Xvalues,Xvalues,'k','linewidth',2)
plot(diag(Xvalues)*sd,diag(Xvalues)*Sd,'r','linewidth',2)
plot(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,'b','linewidth',2)
plot(ones(length(Xvalues),1)*sk_P,Xvalues,'b','linewidth',1)
plot(Xvalues,ones(length(Xvalues),1)*Sk_P,'b','linewidth',1)
plot(ones(length(Xvalues),1)*sd,Xvalues,'r','linewidth',1)
plot(Xvalues,ones(length(Xvalues),1)*Sd,'r','linewidth',1)
axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)])
subplot(2,2,4); plot(Xvalues,-npdfs); axis([Xvalues(1) Xvalues(end) -max(npdfs)*1.1 0]); grid on; h2 = gca;
subplot(2,2,1); plot(-npdfS,Xvalues); axis([-max(npdfS)*1.1 0 Xvalues(1) Xvalues(end)]); grid on; h3 = gca; 
set(h1,'Position',[0.35 0.35 0.55 0.55]);
set(h2,'Position',[.35 .1 .55 .15]);
set(h3,'Position',[.1 .35 .15 .55]);

figure
surf(Xvalues,Xvalues,pMk)
hold on
xlabel('Sollecitazione (s) [stress units]')
ylabel('Resistenza (S) [stress units]')
zlabel('f(x) PDF')
title('Funzione di densit di Probabilit Congiunta')
plot3(Xvalues,ones(length(Xvalues),1)*0,npdfs*(max(max(npdfsS))/max(npdfs)),'k')
plot3(ones(length(Xvalues),1)*0,Xvalues,npdfS*(max(max(npdfsS))/max(npdfS)),'k')
plot3(diag(Xvalues),diag(Xvalues),ones(length(Xvalues),1)*0,'k','linewidth',2)
plot3(diag(Xvalues)*sd,diag(Xvalues)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',2)
hold on
plot3(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',2)
% plot3(0,S_P,S_p*(max(max(npdfsS))/max(npdfS)),'ro','linewidth',2)
% plot3(s_P,0,s_p*(max(max(npdfsS))/max(npdfs)),'bo','linewidth',2)
plot3(ones(length(Xvalues),1)*sk_P,Xvalues,ones(length(Xvalues),1)*0,'b','linewidth',1)
plot3(Xvalues,ones(length(Xvalues),1)*Sk_P,ones(length(Xvalues),1)*0,'b','linewidth',1)
plot3(ones(length(Xvalues),1)*sd,Xvalues,ones(length(Xvalues),1)*0,'r','linewidth',1)
plot3(Xvalues,ones(length(Xvalues),1)*Sd,ones(length(Xvalues),1)*0,'r','linewidth',1)
Ax=axis;
axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end) Ax(5) Ax(6)])

figure
subplot(2,2,2); contour3(Xvalues,Xvalues,pMd,50) ;axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)]); h1 = gca;
title('Simulated Dependent Sigma and Strength Values');
xlabel('X1 ~ Sigma'); ylabel('X2 ~ Strength');
hold on
plot(Xvalues,Xvalues,'k','linewidth',2)
plot(diag(Xvalues)*sd,diag(Xvalues)*Sd,'r','linewidth',2)
plot(diag(Xvalues)*sk_P,diag(Xvalues)*Sk_P,'b','linewidth',2)
plot(ones(length(Xvalues),1)*sk_P,Xvalues,'b','linewidth',1)
plot(Xvalues,ones(length(Xvalues),1)*Sk_P,'b','linewidth',1)
plot(ones(length(Xvalues),1)*sd,Xvalues,'r','linewidth',1)
plot(Xvalues,ones(length(Xvalues),1)*Sd,'r','linewidth',1)
axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)])
subplot(2,2,4); plot(Xvalues,-npdfs); axis([Xvalues(1) Xvalues(end) -max(npdfs)*1.1 0]); grid on; h2 = gca;
subplot(2,2,1); plot(-npdfS,Xvalues); axis([-max(npdfS)*1.1 0 Xvalues(1) Xvalues(end)]); grid on; h3 = gca; 
set(h1,'Position',[0.35 0.35 0.55 0.55]);
set(h2,'Position',[.35 .1 .55 .15]);
set(h3,'Position',[.1 .35 .15 .55]);

figure
subplot(2,2,2); contour3(Xvalues,Xvalues,pM,50) ;axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)]); h1 = gca;
title('Simulated Dependent Sigma and Strength Values');
xlabel('X1 ~ Sigma'); ylabel('X2 ~ Strength');
hold on
plot(Xvalues,Xvalues,'k','linewidth',2)
axis([Xvalues(1) Xvalues(end) Xvalues(1) Xvalues(end)])
subplot(2,2,4); plot(Xvalues,-npdfs); axis([Xvalues(1) Xvalues(end) -max(npdfs)*1.1 0]); grid on; h2 = gca;
subplot(2,2,1); plot(-npdfS,Xvalues); axis([-max(npdfS)*1.1 0 Xvalues(1) Xvalues(end)]); grid on; h3 = gca; 
set(h1,'Position',[0.35 0.35 0.55 0.55]);
set(h2,'Position',[.35 .1 .55 .15]);
set(h3,'Position',[.1 .35 .15 .55]);
