function [Ks,Ke,Kf,emax,smax] = material_e4(Sut,E,Kt,q,sn,ns,Ks,sfs,efs,Plots)


% E      Elastic modulus
% Sut    Ultimate tensile strength
% Kt     Theoretical stress concentration factor
% q      Notch sensitivity factor
% sn     Nominal stress

%Cyclic loading
% ns    
% Ks      
% sfs    
% efs    

% Plots  plot S-E curve

%________________________________

%S-E curve
s_c=Sut/1000:Sut/1000:2*Sut;

for i=1:length(s_c),
    es_c(i)=s_c(i)/E+(s_c(i)/Ks)^(1/ns);
end
%________________________________

%________________________________

%Neuber Hyperbola

Kf=1+q*(Kt-1);

for i=1:length(s_c),
    es_h(i)=Kf^2*sn^2/(E*s_c(i));
end

differ=es_h-es_c;

[a b]=min(abs(differ));

if Plots==1,

figure
plot(es_c,s_c,'b','linewidth',2)
hold on
plot(es_h,s_c,'r','linewidth',2)
grid on
title('Cyclic stress-strain curve (b) and Neuber hyperbola (r)')
xlabel('strain')
ylabel('sigma (stress unit)')
axis([1e-4 0.01 10 1.2*Sut])
[emax smax]=ginput(1)
Ks=smax/sn;
Ke=emax/(sn/E);

else

emax=es_c(b);
smax=s_c(b);
Ks=smax/sn;
Ke=emax/(sn/E);
    
end