close all
clear all
clc

%Punto con cui entrare nel piano di Haigh
sm=200;
sa=400;
Csa=0.15;
Csm=0.15;

%Condizione di sollecitazione Flessionale
d=20; %(mm)
t=70; %F
r=5; %(mm) Foro

Sut=1200;
Sy=0.8*Sut;
Csut=0.044;
Kso=0.9;
Nse=1e6;
Kse=0.504;
Cse=0.146;
Rel=95;
Kb=1/3;

ka=1.58*Sut^-0.085;
Cka=0.13;
kb=(d/7.63)^-0.1133;
Ckb=0;
kc=1;
Ckc=0;
kd=(0.975+0.432e-3*t-0.115e-5*t^2+0.104e-8*t^3-0.595e-12*t^4);
Ckd=0.11;
a=0.025*(2070/Sut)^1.8;
ke=1;
Cke=0;

K=ka*kb*kc*kd*ke;;
Ck=sqrt(Cka^2+Ckb^2+Ckc^2+Ckd^2+Cke^2);

Plots=1;

[Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots);


%Verifica di resistenza a Cicli assegnati
Nf=1e5;
Sf=Wb(1)*Nf^Wb(2);
%Coefficiente di variazione
Cf=2*Csut-Cse+1/3*(Cse-Csut)*log10(Nf);
%Deviazione standard
sSf=Sf*Cf;

stress=[1 sm sa];
%ES=0; %Goodman (Sa / Se + Sm / Sut = 1) 
%ES=1; %Gerber (Sa / Se + (Sm / Sut)^2 = 1) 
%ES=2; %No Correction
ES=0;
[stress_eqv] = eqvspec(stress, Sut, ES);

Orizz1=[1 Nf];
Vert1=[Sf Sf];
Orizz2=[Nf Nf];
Vert2=[10 Sf];

figure(1)
hold on
loglog(Orizz1,Vert1,'c--')
loglog(Orizz2,Vert2,'c--')
loglog(Nf,Sf,'*b')		

% Curve sul piano di Haigh

x1=0:Sut/100:Sut;
x2=0:Sy/100:Sy;

figure(2)
% Curva di Goodman
ygo=Sf*(1-x1/Sut);
Goodman=plot(x1,ygo,'b');
set(Goodman,'Linewidth',1)
axis ([0 1.1*Sut 0 1.1*Sy])

hold on

% Curva di Gerber
yge=Sf*(1-(x1.^2/Sut^2));
Gerber=plot(x1,yge,'r');
set(Gerber,'Linewidth',1)

% Curva di Sodeberg
yso=Sf*(1-x2/Sy);
Sodeberg=plot(x2,yso,'g');
set(Sodeberg,'Linewidth',1)

% Curva ASME
yasme=Sf*(1-(x2.^2/Sy^2)).^(1/2);
ASME=plot(x2,yasme,'m');
set(ASME,'Linewidth',1)

% Curva di Bagci
yba=Sf*(1-(x2.^4/Sy^4));
Bagci=plot(x2,yba,'c');
set(Bagci,'Linewidth',1)

% Curva di Langer
yla=Sy*(1-x2/Sy);
Langer=plot(x2,yla,'k--');
set(Langer,'Linewidth',1)

grid on
title('Piano di Haigh')
xlabel('Tensione media     MPa')
ylabel('Tensione alterna     MPa')
text(Sy,Sy,'Goodman (b)')
text(Sy,0.9*Sy,'Gerber (r)')
text(Sy,0.8*Sy,'Sodeberg (g)')
text(Sy,0.7*Sy,'ASME (m)')
text(Sy,0.6*Sy,'Bagci (c)')

% Punto di lavoro
% tensione alterna
siga=sa; %MPa
% tensione media
sigm=sm; %MPa

Csiga=Csa;
ssa=Csiga*siga;
Csigm=Csm;
ssm=Csigm*sigm;

Orizz1=[0 sigm];
Vert1=[siga siga];
Orizz2=[sigm sigm];
Vert2=[0 siga];

figure(2)
hold on
plot(Orizz1,Vert1,'c--')
plot(Orizz2,Vert2,'c--')
plot(sigm,siga,'*k')

Plots=0;

% Coefficienti di sicurezza con tensioni media ed alterna proporzionali
[A]=SCoeffProp(Sut,Sy,Sf,sigm,siga);

% Tensione media costante, tensione alterna variabile
[Am]=SCoeffSmCost(Sut,Sy,Sf,sigm,siga,Plots);

% Tensione alterna costante, tensione media variabile
[Aa]=SCoeffSaCost(Sut,Sy,Sf,sigm,siga,Plots);


[A Aa Am]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%A(1)
n_cm=(Sf*Sut)/(siga*Sut+sigm*Sf)

if n_cm < 1
    Nf=(stress_eqv(1,2)/Wb(1))^(1/Wb(2))
end

r=siga/sigm;

Sa=n_cm*siga;
% Sm=n_cm*sigm;
Sm=Sa/r;


Orizz1=[0 sigm];
Vert1=[siga siga];
Orizz2=[sigm sigm];
Vert2=[0 siga];
Orizz3=[0 Sm];
Vert3=[Sa Sa];
Orizz4=[Sm Sm];
Vert4=[0 Sa];

figure(3)
% Curva di Goodman
ygo=Sf*(1-x1/Sut);
Goodman=plot(x1,ygo,'k');
set(Goodman,'Linewidth',2)
axis ([0 2*Sut 0 2*Sf])
hold on
grid on
title('Piano di Haigh')
xlabel('Tensione media     MPa')
ylabel('Tensione alterna     MPa')
plot(Orizz1,Vert1,'r--')
plot(Orizz2,Vert2,'r--')
plot(sigm,siga,'*r','linewidth',2)
plot([0:10:Sut],r*[0:10:Sut],'c--','linewidth',1)
plot(Orizz3,Vert3,'k--')
plot(Orizz4,Vert4,'k--')
plot(Sm,Sa,'*k','linewidth',2)
%axis equal

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Pkm=0.999;
sSf;
sSut=Csut*Sut;

zk=norminv(Pkm,0,1);
Sfkm_p=sSf*(zk)+Sf;
Sfkm_m=sSf*(-zk)+Sf;
Sutkm_p=sSut*(zk)+(Sut);
Sutkm_m=sSut*(-zk)+(Sut);

siga_p=ssa*(zk)+siga;
siga_m=ssa*(-zk)+siga;
sigm_p=ssm*(zk)+sigm;
sigm_m=ssm*(-zk)+sigm;

figure(3)
plot([0 Sutkm_p],[Sfkm_p 0],'k','linewidth',1)
plot([0 Sutkm_m],[Sfkm_m 0],'k','linewidth',1)

%%

%%%
%%% Approccio in analogia a quello seguito nella "Verifica statica ed Affidabilit" pag. 13
%%%

t1=sqrt(Sm^2+(Sf-Sa)^2)/sqrt(Sut^2+Sf^2);
t2=sqrt(Sa^2+(Sut-Sm)^2)/sqrt(Sut^2+Sf^2);
CSa=-(abs(Csut-Cf)*t1)+Cf;
CSm=+(abs(Csut-Cf)*t2)+Csut;
sSa=CSa*(Sa);
sSm=CSm*(Sm);

Sa_p=sSa*(zk)+Sa;
Sa_m=sSa*(-zk)+Sa;
Sm_p=sSm*(zk)+Sm;
Sm_m=sSm*(-zk)+Sm;


%%%
%%% Analogamente all'Approccio consigliato nella verifica statica (Verifica statica ed Affidabilit pag. 13)
%%%

S=Sa;
s=sa;
ss=ssa;
sS=sSa;
 
% S=Sm;
% s=sm;
% ss=ssm;
% sS=sSm;

Xvalues=[0:10:2*Sut];

clear  npdfS npdfs npdfsS

npdfS=normpdf(Xvalues,S,sS);
npdfs=normpdf(Xvalues,s,ss);
npdfz=normpdf(Xvalues,(S-s),(sqrt(ss^2+sS^2)));
for i=1:length(Xvalues),
    npdfsS(i,:)=npdfS(i)*npdfs;
end

[z,R]=eqacc_norm(S,sS,s,ss)

p=normspec([-inf 0],(S-s),(sqrt(ss^2+sS^2)));
hold on
plot(Xvalues,npdfS,'k','linewidth',2)
plot(Xvalues,npdfs,'r','linewidth',2)
plot(Xvalues,npdfz,'b','linewidth',2)
grid on
xlabel('Sollecitazione/Resistenza [stress units]')
ylabel('f(x) PDF')
str = ['Probability S vs s Between Limits is ',num2str(p)];
title(str)

