function [Wb,N,S,Sr,Sw,Sah,Sm] = wohler3D(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Nh, Smw, Rf)

%i.e. [Wb,N,S,Sr,Sw,Sah,Sm] = wohler3D(500, 0.044, 1e6, 0.44, 0.9, 1/2, 1/3, 90, 0.060/0.44, 0, 1e4 ,100, 0);

% material strenght
% Csut   coefficient of variation of Sut
% endurance limit cycles number (cycle)
% material fatigue ratio at Nse cycles (Bending)
% material fatigue ratio at N=10^3 cycles
% endurance limit modifying factor 
% slope coefficient for stress life after Nse cycles 
% reliability (%)
% coefficient of variation of Kse coefficient
% coefficient of variation of K coefficient
% cycle number at which to evaluate gerber curve
% mean stress value at which to evaluate wohler curve
% Rf ratio Smin/Smax at which to evaluate wohler curve > -1

N0=1.00000E+03;  	                    %Cycles	
Nlim=1.00000E+010;  	                %Cycles	

N=[1 N0 2.5e3 5e3 7.5e3 1e4 2.5e4 5e4 7.5e4 1e5 2.5e5 5e5 7.5e5 1e6 2.5e6 5e6 7.5e6 1e7 2.5e7 5e7 7.5e7 1e8 2.5e8 5e8 7.5e8 1e9 2.5e9 5e9 7.5e9 Nlim];
S=zeros(length(N),1);

R=norminv(Rel/100,0,1);
C=sqrt(Cse^2+Ck^2);
Cso=sqrt(Csut^2+Ck^2);
Krso=1-Cso*R;  %modifying factor (reliability) at N=10^3 cycles
Krse=1-C*R;    %modifying factor (reliability) at Nse cycles

S0=Kso*Krso*Sut;
Se=Kse*K*Krse*Sut;	                     
Sut1=Sut*Krso;
b1=Log10(Se/S0)/Log10(Nse/N0);
a1=(S0)/N0^b1;
b2=Kb*b1;
a2=exp(log(Se)-b2*log(Nse));	         

Sm=0:Sut1/(length(N)-1):Sut1;
Sa=zeros(length(Sm),length(N));
Sa1=Sa;

S(1)=Sut1;
Sa(:,1)=Sut1*(1-(Sm/Sut1))';
Sa1(:,1)=Sut1*(1-(Sm/Sut1))';
Su(:,1)=Sut1*(1-(Sm/Sut1))';

for i=2:length(N),
S(i)=a1*N(i)^b1;
Sa(:,i)=S(i)*(1-(Sm/Sut1).^2)';
Sa1(:,i)=S(i)*(1-(Sm/Sut1))';
Su(:,i)=Sut1*(1-(Sm/Sut1))';
end

for i=2:length(N),
if N(i)>=Nse,
    S(i)=a2*N(i)^b2;
    Sa(:,i)=S(i)*(1-(Sm/Sut1).^2)';
    Sa1(:,i)=S(i)*(1-(Sm/Sut1))';
else
end
end

Sh=a1*Nh^b1;
Sah(:,1)=Sh*(1-(Sm/Sut1).^2)';
Sa1h(:,1)=Sh*(1-(Sm/Sut1))';

if Nh>=Nse,
    Sh=a2*Nh^b2;
    Sah(:,1)=Sh*(1-(Sm/Sut1).^2)';
    Sa1h(:,1)=Sh*(1-(Sm/Sut1))';
else
end

Sw(1)=Sut1;

for i=2:length(N),
Sw(i)=(1-(Smw/Sut1)^2)*a1*N(i)^b1;
end

for i=2:length(N),
if N(i)>=Nse,
    Sw(i)=(1-(Smw/Sut1)^2)*a2*N(i)^b2;
else
end
end

Sr(1)=Sut1/2*(1-Rf);
Smr(1)=Sut1/2*(1+Rf);

for i=2:length(S),
a=S(i)*(1+Rf^2+2*Rf);
b=2*Sut1^2*(1-Rf);
c=-4*Sut1^2*S(i);
Smax(i)=(-b+sqrt(b^2-4*a*c))/(2*a);
%Stmp=1/((1-Rf)/(2*S(i))+(1+Rf)/(2*Sut1));
%Smax(i)=Stmp;
Sr(i)=Smax(i)/2*(1-Rf);
Smr(i)=Smax(i)/2*(1+Rf);
end

A=Sa;
A1=Sa1;
Ab=Sah;
A1b=Sa1h;
B=Su;
C=Sm;
A(length(Sa),:)=1/500*Sut*ones(length(Sa),1)';
A1(length(Sa1),:)=1/500*Sut*ones(length(Sa1),1)';
Ab(length(Sah))=1/500*Sut;
A1b(length(Sa1h))=1/500*Sut;
B(length(Su),:)=1/500*Sut*ones(length(Su),1)';
C(1)=1/500*Sut;

figure

p=loglog(N(2:length(N)),S(2:length(N)),'r');
set(p,'Linewidth',2);
hold on
p=loglog(N(1:2),S(1:2),'r--');
set(p,'Linewidth',2);
grid on
title('Wohler Curve (pure alterning (r,b) and reversal (g) bending)')
xlabel('Cycles log(N)')
ylabel('Stress amplitude log(Stress unit)')
p=loglog(N(1:2),Sw(1:2),'b--');
set(p,'Linewidth',2);
p=loglog(N(2:length(N)),Sw(2:length(N)),'b');
set(p,'Linewidth',2);
p=loglog(N(1:2),Sr(1:2),'g--');
set(p,'Linewidth',2);
p=loglog(N(2:length(N)),Sr(2:length(N)),'g');
set(p,'Linewidth',2);

figure

p=plot(Sm,Sah,'r');
set(p,'Linewidth',2);
grid on
hold on
title('Haigh Diagram - Gerber curve (-) Goodman curve (--)')
xlabel('Stress mean (Stress unit)')
ylabel('Stress amplitude (Stress unit)')
p=plot(Sm,Sa1h,'r:');
set(p,'Linewidth',2);

figure

subplot(4,2,1:6)
surf(N,C,A);
hold on
p=plot3(N,C(1)*ones(length(N),1),A(1,:),'r');
set(p,'Linewidth',3);
p=plot3(N,Smw*ones(length(N),1),Sw,'b');
set(p,'Linewidth',3);
p=plot3(N,Smr,Sr,'g');
set(p,'Linewidth',3);
p=plot3(Nh*ones(length(N)),C,Ab,'r');
set(p,'Linewidth',3);
p=plot3(N,C(length(Sm))*ones(length(Sm),1),A(length(A),:),'k');
set(p,'Linewidth',3);
title('3D representation of Fatigue strength')
xlabel('Cycles log(N)')
ylabel('Stress mean (Stress unit)')
zlabel('Stress amplitude log(Stress unit)')

subplot(4,2,7)
p=loglog(N(2:length(N)),S(2:length(N)),'r');
set(p,'Linewidth',2);
hold on
p=loglog(N(1:2),S(1:2),'r--');
set(p,'Linewidth',2);
grid on
title('Wohler Curve (pure alterning (r,b) and reversal (g) bending)')
xlabel('Cycles log(N)')
ylabel('Stress amplitude log(Stress unit)')
p=loglog(N(1:2),Sw(1:2),'b--');
set(p,'Linewidth',2);
p=loglog(N(2:length(N)),Sw(2:length(N)),'b');
set(p,'Linewidth',2);
p=loglog(N(1:2),Sr(1:2),'g--');
set(p,'Linewidth',2);
p=loglog(N(2:length(N)),Sr(2:length(N)),'g');
set(p,'Linewidth',2);

subplot(4,2,8)
p=plot(C,Ab,'r');
set(p,'Linewidth',2);
grid on
hold on
title('Haigh Diagram - Gerber curve (-) Goodman curve (--)')
xlabel('Stress mean (Stress unit)')
ylabel('Stress amplitude (Stress unit)')
p=plot(C,A1b,'r--');
set(p,'Linewidth',2);

Wb=[a1 b1 a2 b2]';
N=N';
S=S';
Sa=Sa;
Sm=Sm';

