close all
clear all
clc

% Albero
d=35; %(mm)
t=70; %F
r=3; %(mm) Raccordo

Sut=1000;
Sy=0.8*Sut;
Csut=0.044;
Kso=0.9;
Nse=1e6;
Kse=0.504;
Cse=0.146;
Rel=95;
Kb=1/3;

ka=4.51*Sut^-0.265;
Cka=0.06;
kb=(d/7.63)^-0.1133;
Ckb=0;
kc=1;
Ckc=0;
kd=(0.975+0.432e-3*t-0.115e-5*t^2+0.104e-8*t^3-0.595e-12*t^4);
Ckd=0.11;
a=0.025*(2070/Sut)^1.8;
q=1/(1+a/r);
Kt=1.75;
Kf=1+q*(Kt-1);
ke=1/Kf;
Cke=0.08;

K=ka*kb*kc*kd*ke;
Ck=sqrt(Cka^2+Ckb^2+Ckc^2+Ckd^2+Cke^2);

Plots=1;
[Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots);
hold on

numc=50000;
dt=0.1;
time=0:dt:(numc-1)*dt;

sn = 300;

input=sn*randn(numc,1);
nf=1/(2*dt);
fl=1;
W=fl/nf;
[B,A] =butter(3,W);
input=filtfilt(B,A,input);

figure(2)
plot(time,input)
signal=[time' input];
hold on
grid on
xlabel('time (s)')
ylabel('stress (units)')

% count=1; %Rainflow 
% count=2; %Peak-Valley 
count=1;
if count==1
%     P3D=1;  %RainFlow Matrix plot 3dimensional
%     P3D=0;  %RainFlow Matrix plot 2dimensional
%     RES=0; %No Residuals 
%     RES=1; %Residuals (Cloormann/Seeger) 
    P3D=0;
    RES=1;
    fil=0;
    num=50;
    [tp,rfc,spettro,res] = conteggio(signal,fil,num,RES,P3D,Plots);

    figure(2)
    plot(tp(:,1),tp(:,2),'k*')
    plot(tp(:,1),tp(:,2),'ro')

    if RES==0
        figure
        plot(res(:,1),res(:,2))
        hold on
        grid on
        xlabel('time (s)')
        ylabel('stress (units)')
        title('Residuals')
    end
else
    close (2)
    [spettro] = PVcount(signal,Plots);
end

% ES=0; %Goodman (Sa / Se + Sm / Sut = 1) 
% ES=1; %Gerber (Sa / Se + (Sm / Sut)^2 = 1) 
% ES=2; %No Correction
ES=0;
[speceqv] = eqvspec(spettro, Sut, ES);

saeqv1=(sum(speceqv(:,1).*(speceqv(:,2).^(-1/Wb(2))))/sum(speceqv(:,1)))^(-Wb(2))
neqv1=sum(speceqv(:,1))
Neqv1=(saeqv1/Wb(1))^(1/Wb(2))
nN1=Neqv1/neqv1
Seqv1=Wb(1)*neqv1^(Wb(2))
nS1=Seqv1/saeqv1

figure(6)
loglog(N,S,'b', 'linewidth',2)
grid on
title('Wohler Curve (bending)')
xlabel('Cycles log(N)')
ylabel('Stress amplitude log(Stress unit)')
axis([N(1) N(4) S(4) 1.1*S(1)])
hold on
plot(neqv1,saeqv1,'kx')
plot(neqv1,Seqv1,'ko')
plot(Neqv1,saeqv1,'ko')

% Ricostruzione pdf sperimentale
plotid=0;
num=50;
[x_r, y_r]=plotta_pdf(speceqv,num,3,'r',plotid);
pdf_r(:,2)=x_r;
pdf_r(:,1)=y_r;

figure(300)
hold on
plot(pdf_r(:,2),pdf_r(:,1),'b','linewidth',1)
p=axis;
axis([0 p(2) 0 p(4)])
grid on
ylabel('Pdf')
xlabel('units')
title('Pdf di carico')

figid=100;
spe_r = cumula(speceqv,'r',0,figid);
figure(figid)
hold on
semilogx([1 sum(speceqv(:,1))],[saeqv1 saeqv1],'k')
figid=110;
spe_r = cumula(speceqv,'r',1,figid);

Miner_D=1;
type=0;
[Dcum] = damage(speceqv, Miner_D, S, Wb, type)
Life=Miner_D/Dcum
saeqv2=((sum(speceqv(:,1))/Dcum)^Wb(2))*Wb(1)
neqv2=sum(speceqv(:,1))
Neqv2=(saeqv2/Wb(1))^(1/Wb(2))
nN2=Neqv2/neqv2
Seqv2=Wb(1)*neqv2^(Wb(2))
nS2=Seqv2/saeqv2

figure(6)
plot(neqv2,saeqv2,'bx')
plot(neqv2,Seqv2,'bo')
plot(Neqv2,saeqv2,'bo')

loglog(spe_r(:,1),spe_r(:,2),'r')
p=axis;
axis([p(1) p(2) min(spe_r(:,2)) p(4)])

figid=100;
figure(figid)
hold on
semilogx([1 sum(speceqv(:,1))],[saeqv2 saeqv2],'b')

[Wb_m, Dcum_m] = manson(speceqv, Miner_D, Wb, N, S)
Smans=S(1:3);
Smans(3)=Wb_m(1)*N(3).^Wb_m(2);
figure(6)
p=loglog(N(2:3,1),Smans(2:3,1),'k');
set(p,'Linewidth',2);
p=loglog(N(1:2,1),Smans(1:2,1),'k--');
set(p,'Linewidth',1);




