clear all
close all
clc

%Curva di resistenza a fatica
Sut=700;
Sy=0.8*Sut;
Csut=0.044;
Kso=0.9;
Nse=1e6;
Kse=0.504;
Cse=0.146;
Rel=95;
Kb=3/5;
%
ka=57.7*Sut^-0.718;
Cka=0.11;
kb=1;
Ckb=0;
kc=1;
Ckc=0;
kd=1;
Ckd=0;
q=0.6;
Kt=3;
Kf=1+q*(Kt-1);
ke=1/Kf;
Cke=0.10;
%
K=ka*kb*kc*kd*ke;
Ck=sqrt(Cka^2+Ckb^2+Ckc^2+Ckd^2+Cke^2);
%
Plots=1;
[Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots);
hold on


%Calcolo curva normativa (es. classe 100)
curvanorm=0;

if curvanorm==1
    clear S
    clear N

    b1=-1/3;
    b2=-1/5;
    Nstar=2e6;
    Sstar=100;
    loga1=log(Sstar)-b1*log(Nstar);
    a1=exp(loga1);
    Nstar=5e6;
    Sstar=a1*Nstar^b1
    loga2=log(Sstar)-b2*log(Nstar);
    a2=exp(loga2);
    N=[1 1e3 5e6 1e8 2e8]
    S=zeros(length(N),1);
    S(2)=a1*N(2)^b1;
    S(1)=1.1*S(2);
    S(3)=a1*N(3)^b1;
    S(4)=a2*N(4)^b2;
    S(5)=S(4);
    S=(S/2)';
    Wb=[a1 b1 a2 b2]';

    figure(1)
    loglog(N,S,'k','Linewidth',2);
    hold on
    grid on
    title('Wohler Curve (bending)')
    xlabel('Cycles log(N)')
    ylabel('Stress amplitude log(Stress unit)')
    axis([1e4 2e8 10 2000])
end

%Spettro di carico
cicli_max=20000;
carico_max=100000; %Carico massimo [N]
perc_carichi=[0.975 0.944 0.906 0.856 0.787 0.666]; %Percentuale del carico massimo ad intervallo (da normativa)
Cc=[0.01 0.01 0.05 0.05 0.05 0.05];
sc=perc_carichi.*Cc;
classi=length(perc_carichi);

for i=1:classi;
    spettro(i)=(i/classi*log10(cicli_max));
    spettro_t(i)=(10^spettro(i));
    %%%conteggio del numero dei cicli relativo ad ogni intervallo dello
    %%%spettro di carico (da normativa)%%%
    if i==1
        spettro_inc(i)=spettro_t(i);
    else
        spettro_inc(i)=spettro_t(i)-spettro_t(i-1); % cicli ad intervallo
    end
    perc_spettro(i)=((spettro_inc(i)/cicli_max)); % percentuale cilci per ogni intervallo
end

caricot=0;
caricok=0;
Caricot=zeros(cicli_max,classi);
Caricok=zeros(cicli_max,classi);

for i=1:classi
  carico_tmp=perc_carichi(i)*carico_max+carico_max*Cc(i)*randn(round(spettro_inc(i)),1);
  caricok_tmp=ones(round(spettro_inc(i)),1)*perc_carichi(i)*carico_max;
  Caricot(1:round(spettro_inc(i)),i)=carico_tmp;
  Caricok(1:round(spettro_inc(i)),i)=caricok_tmp;
  caricot=[caricot;carico_tmp];
  caricok=[caricok;caricok_tmp];
end

caricot=caricot(2:end);
caricok=caricok(2:end);

spettrot=[ones(length(caricot),1) caricot];
spettrok=[ones(length(caricok),1) caricok];
nt=sum(spettrot(:,1))
Peqvt=(sum(spettrot(:,1).*(spettrot(:,2).^(-1/Wb(2))))/sum(spettrot(:,1)))^(-Wb(2))
Peqvk=(sum(spettrok(:,1).*(spettrok(:,2).^(-1/Wb(2))))/sum(spettrok(:,1)))^(-Wb(2))

%Coefficiente di spettro
Kp=(sum(spettrot(:,1).*((spettrot(:,2)/carico_max).^(-1/Wb(2))))/sum(spettrot(:,1)))
Kpk=(sum(spettrok(:,1).*((spettrok(:,2)/carico_max).^(-1/Wb(2))))/sum(spettrok(:,1)))
alfa=Kp^(-Wb(2));
alfak=Kpk^(-Wb(2));
Peqvkp=alfa*carico_max
Peqvkpk=alfak*carico_max

figid=1000;
figure(figid)
semilogx(caricot,'b')
hold on
semilogx(caricok,'r--','linewidth',2)
cumulativo=cumula(spettrot,'k',0,figid);
semilogx(Peqvt*ones(nt,1),'k--','linewidth',2)
plot(round(perc_spettro*nt),perc_carichi*carico_max,'ro','linewidth',2)
plot(round(perc_spettro*nt),perc_carichi*carico_max,'r','linewidth',1)
xlabel('Cicli');
ylabel('Carico [N]');
title('SPETTRO PROGETTO vs SPETTRO REALE');
semilogx(Peqvkp*ones(nt,1),'r--','linewidth',1)
semilogx(Peqvkpk*ones(nt,1),'r--','linewidth',1)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Tensioni
coeff_sigma=(1/4*Sy)/max(caricot);

caricot=coeff_sigma*shuffle(caricot);
time=[1:2*length(caricot)]';
signal=zeros(2*length(caricot),2);
for i=1:1:length(caricot),
    signal(i*2,2)=caricot(i);
end
signal(:,1)=time;

figure(2)
plot(time, signal(:,2))
grid on
xlabel('Tempo')
ylabel('Stress')
hold on


% count=1; %Rainflow 
% count=2; %Peak-Valley 
count=1;
if count==1
%     P3D=1;  %RainFlow Matrix plot 3dimensional
%     P3D=0;  %RainFlow Matrix plot 2dimensional
%     RES=0; %No Residuals 
%     RES=1; %Residuals (Cloormann/Seeger) 
    P3D=0;
    RES=1;
    fil=0;
    num=50;
    [tp,rfc,spettro,res] = conteggio(signal,fil,num,RES,P3D,Plots);

    figure(2)
    plot(tp(:,1),tp(:,2),'k*')
    plot(tp(:,1),tp(:,2),'ro')

    if RES==0
        figure
        plot(res(:,1),res(:,2))
        hold on
        grid on
        xlabel('time (s)')
        ylabel('stress (units)')
        title('Residuals')
    end
else
    close (2)
    [spettro] = PVcount(signal,Plots);
end

% ES=0; %Goodman (Sa / Se + Sm / Sut = 1) 
% ES=1; %Gerber (Sa / Se + (Sm / Sut)^2 = 1) 
% ES=2; %No Correction
ES=0;
[speceqv] = eqvspec(spettro, Sut, ES);
%[speceqv] = eqvspec(rfc, Sut, ES);

saeqv1=(sum(speceqv(:,1).*(speceqv(:,2).^(-1/Wb(2))))/sum(speceqv(:,1)))^(-Wb(2))
neqv1=sum(speceqv(:,1))
Neqv1=(saeqv1/Wb(1))^(1/Wb(2))
nN1=Neqv1/neqv1
Seqv1=Wb(1)*neqv1^(Wb(2))
nS1=Seqv1/saeqv1

figure(6)
loglog(N,S,'b', 'linewidth',2)
grid on
title('Wohler Curve (bending)')
xlabel('Cycles log(N)')
ylabel('Stress amplitude log(Stress unit)')
if curvanorm==0
    axis([N(1) N(4) S(4) 1.1*S(1)])
else
    axis([1 2e8 10 2000])
end
hold on
plot(neqv1,saeqv1,'kx')
plot(neqv1,Seqv1,'ko')
plot(Neqv1,saeqv1,'ko')

% Ricostruzione pdf sperimentale
plotid=0;
num=50;
[x_r, y_r]=plotta_pdf(speceqv,num,3,'r',plotid);
pdf_r(:,2)=x_r;
pdf_r(:,1)=y_r;

figure(300)
hold on
plot(pdf_r(:,2),pdf_r(:,1),'b','linewidth',1)
p=axis;
axis([0 p(2) 0 p(4)])
grid on
ylabel('Pdf')
xlabel('units')
title('Pdf di carico')

figid=100;
spe_r = cumula(speceqv,'r',0,figid);
figure(figid)
hold on
semilogx([1 sum(speceqv(:,1))],[saeqv1 saeqv1],'k')
figid=110;
spe_r = cumula(speceqv,'r',1,figid);

Miner_D=1;
type=0;
[Dcum] = damage(speceqv, Miner_D, S, Wb, type)
Life=Miner_D/Dcum
saeqv2=((sum(speceqv(:,1))/Dcum)^Wb(2))*Wb(1)
neqv2=sum(speceqv(:,1))
Neqv2=(saeqv2/Wb(1))^(1/Wb(2))
nN2=Neqv2/neqv2
Seqv2=Wb(1)*neqv2^(Wb(2))
nS2=Seqv2/saeqv2

figure(6)
plot(neqv2,saeqv2,'bx')
plot(neqv2,Seqv2,'bo')
plot(Neqv2,saeqv2,'bo')

loglog(spe_r(:,1),spe_r(:,2),'r')
p=axis;
%axis([p(1) p(2) min(spe_r(:,2)) p(4)])

figid=100;
figure(figid)
hold on
semilogx([1 sum(speceqv(:,1))],[saeqv2 saeqv2],'b')

[Wb_m, Dcum_m] = manson(speceqv, Miner_D, Wb, N, S)
Smans=S(1:3);
Smans(3)=Wb_m(1)*N(3).^Wb_m(2);
if curvanorm==0
    figure(6)
    p=loglog(N(2:3,1),Smans(2:3,1),'k');
    set(p,'Linewidth',2);
    p=loglog(N(1:2,1),Smans(1:2,1),'k--');
    set(p,'Linewidth',1);
end

%Spettro
Peqvt
Peqvk
%Coefficiente di spettro
Peqvkp
Peqvkpk
%Tensioni
sigma=coeff_sigma*[Peqvt Peqvk]'
sigma_a=sigma/2;
sigma_m=sigma/2;
sp_sigma=[nt*ones(length(sigma),1) sigma_m sigma_a]

% ES=0; %Goodman (Sa / Se + Sm / Sut = 1) 
% ES=1; %Gerber (Sa / Se + (Sm / Sut)^2 = 1) 
% ES=2; %No Correction
ES=0;
[sp_eqv] = eqvspec(sp_sigma, Sut, ES);

figure(6)
plot(sp_eqv(:,1),sp_eqv(:,2),'go')

figid=100;
figure(figid)
hold on
semilogx([1 nt],[sp_eqv(:,2) sp_eqv(:,2)],'g')
