clear all
close all
clc

%Definizione parametri dinamici
T=1000; %Durata (s) del disturbo random
dt=0.01; %Passo di integrazione o ricostruzione della TH
t=(0:dt:T)'; %Vettore del tempo
df=0.01; %Passo di discertizzazione del vettore della frequenza
maxfreq=1/(2*dt); %Frequenza di Nyquist
freq=df:df:maxfreq; %Vettore della Frequenza
w=2*pi*freq;
fft_point=2048; %punti da utilizzare per l'analisi FFT





%Definizione del Modellon 1dof
csi=0.1; %Smorzamento percentuale
m=10000; %Massa (kg o kg*m^2)
k=1e6; %Rigidezza (N/m o N*m/rad)
w0=sqrt(k/m); %Pulsazione naturale (rad/s)
f0=w0/2/pi; %Frequenza naturale (Hz)
b=2*m*csi*w0; %Smorzamento

%State Space Forza imposta (spostamento e velocit in uscita)
A=[0 1; -w0^2 -b/m];
B=[0; 1/m];
C=[1 0];
D=0;

% %State Space Spostamento imposto
% fb=10*f0;
% p=2*pi*fb;
% A=[0 1 0; -w0^2 -b/m 0; 0 0 -p];
% B=[b/m; w0^2*(1-4*(b/(2*w0*m))^2); -p^2];
% C=[1 0 0; 0 1 0; 1 0 0; 0 1 -1];
% D=[0; -b/m; -1; b/m-p];

SYS=ss(A,B,C,D);
%Generazione della FRF
[mag,phase]=bode(SYS,w);

input=1;
output=1;
%Generazione della FRF
[mag,phase]=bode(SYS,w);





%Definizione PSD dell'ingresso
% AMP=20; %Ampiezza dell'ingresso (ingresso in spostamento)
AMP=2e7; %Ampiezza dell'ingresso (ingresso in forza)
Sn=0*ones(length(freq),1);
for i=1:length(freq),
    Sn(i)=(AMP)^2; %(units)^2/Hz
end
PSDu=Sn; %Disturbo PSD





%Ricostruzione del segnale di ingresso a partire dalla PSD di input
S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','...','date','..','L',400,'Bw',1.2535e+001);
% S = struct('S',(1)/(2*pi)*PSDu,'w',2*pi*freq','tr',[],'h',[],'type','freq','phi',0,'norm',0,'note','..','date','..','L','..','Bw','..');
P2=T/dt;
itime=spec2sdat(S,P2,dt);
[A,B]=spectrum(itime(:,2),fft_point,fft_point/4,hanning(fft_point));

figure(1)
plot(itime(:,1),itime(:,2))
hold on
grid on
xlabel('time (s)')
ylabel('input (units)')

figure(2)
loglog(freq,PSDu,'k','LineWidth',2)
hold on
title('PSD INPUT')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
loglog(B(:,1)*maxfreq,A(:,1)/maxfreq,'r')
axis([0 maxfreq*10 min(PSDu)/10 max(PSDu)*10])





%Analisi dinamica in frequenza
MAG=mag(output,input,:);
MAG=squeeze(MAG(1,1,:));
PSDf=MAG.^2.*PSDu;

figure(3)
subplot(2,1,1)
loglog(freq,squeeze(mag(output,input,:)),'linewidth',1.5)
title('Mag(FRF) dof_2/dof_1')
ylabel('Displacement log(m)')
subplot(2,1,2)
semilogx(freq,squeeze(phase(output,input,:)),'linewidth',1.5)
title('Phase(FRF) dof_2/dof_1')
ylabel('Angle (angle)')
xlabel('freq (Hz)')





% Simulazione nel tempo

time=[0:dt:60]'; %Condizione di carico a gradino
u1=1e8; %Condizione di carico a gradino
outpu=u1*step(SYS,time); %Condizione di carico a gradino
[input1]=step(time,1,5,0,u1); %Condizione di carico a gradino
[input2]=step(time,10,10.1,0,-u1); %Condizione di carico a gradino
input=input1+input2;
outpu=lsim(SYS,input,time); %Condizione di carico a gradino

% time=itime(:,1); %Condizione di carico random
% input=itime(:,2); %Condizione di carico random
% outpu=lsim(SYS,input,time); %Condizione di carico random

outpu=outpu(:,output);
rms_r=std(outpu)

% Analisi in frequenza (PSD) del segnale temporale
[A1,B1]=spectrum(outpu,fft_point,fft_point/4,hanning(fft_point));
freqout=B1(:,1)*maxfreq;
PSDout=A1(:,1)/maxfreq;

figure(4)
plot(time,outpu,'r','LineWidth',0.5)
hold on
title('TH RICOSTRUITA')
xlabel('TIME (s)')
ylabel('OUTPUT (unit)')
grid on

figure(5)
loglog(freqout,PSDout,'r','linewidth',2)
hold on
title('PSD OUTPUT')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
axis([0.5 maxfreq min(PSDout) max(PSDout)*1.2])
loglog(freq,PSDf,'b','linewidth',2)





% Estrazione della funzione di auto-correlazione
[c_ww,lags] = xcorr(outpu,'coeff');

figure(6)
%stem(lags,c_ww)
plot(lags,c_ww)
hold on
grid on
ylabel('autocorrelation function')
xlabel('units')
axis([-2e3 2e3 -1.2 1.2])





% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik
[Mom_ff,Momf] = statPSD(freq,PSDf);    

rms_f = sqrt(Mom_ff(1))
Np_f=sqrt(Mom_ff(5)/Mom_ff(3))
N0p_f=sqrt(Mom_ff(3)/Mom_ff(1))
gamma_f=Mom_ff(3)/sqrt(Mom_ff(1)*Mom_ff(5))





% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik e bendat
deltasigma=10;
[pdf_d,Mom_d] = dirlik(freq,PSDf,deltasigma);    
[pdf_b,Mom_b] = rayleigh(freq,PSDf,deltasigma);    
N_d=deltasigma/2*sqrt(Mom_d(5)/Mom_d(3));
N_b=deltasigma/2*sqrt(Mom_b(5)/Mom_b(3));
spettro_d=[pdf_d(:,1)*T*N_d pdf_d(:,2)];
spettro_b=[pdf_b(:,1)*T*N_b pdf_b(:,2)];
rms_d = sqrt(Mom_d(1));
rms_b = sqrt(Mom_b(1));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Definizione componente e materiale

% Albero
d=35; %(mm)
t=70; %F
r=3; %(mm) Raccordo

Sut=1000;
Sy=0.8*Sut;
Csut=0.044;
Kso=0.9;
Nse=1e6;
Kse=0.504;
Cse=0.146;
Rel=95;
Kb=1/3;

ka=4.51*Sut^-0.265;
Cka=0.06;
kb=(d/7.63)^-0.1133;
Ckb=0;
kc=1;
Ckc=0;
kd=(0.975+0.432e-3*t-0.115e-5*t^2+0.104e-8*t^3-0.595e-12*t^4);
Ckd=0.11;
a=0.025*(2070/Sut)^1.8;
q=1/(1+a/r);
Kt=1.75;
Kf=1+q*(Kt-1);
ke=1/Kf;
Cke=0.08;

K=ka*kb*kc*kd*ke;
Ck=sqrt(Cka^2+Ckb^2+Ckc^2+Ckd^2+Cke^2);

Plots=1;
[Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots);
hold on


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Estrazione dello spettro dei cicli mediante conteggio rainflow nel dominio
%del tempo
signal=[time outpu];

num=100;
% count=1; %Rainflow 
% count=2; %Peak-Valley 
count=1;
if count==1
%     P3D=1;  %RainFlow Matrix plot 3dimensional
%     P3D=0;  %RainFlow Matrix plot 2dimensional
%     RES=0; %No Residuals 
%     RES=1; %Residuals (Cloormann/Seeger) 
    P3D=0;
    RES=1;
    fil=0;
    num=50;
    [tp,rfc,spettro,res] = conteggio(signal,fil,num,RES,P3D,Plots);

    figure(4)
    plot(tp(:,1),tp(:,2),'k*')
    plot(tp(:,1),tp(:,2),'ro')

    if RES==0
        figure
        plot(res(:,1),res(:,2))
        hold on
        grid on
        xlabel('time (s)')
        ylabel('stress (units)')
        title('Residuals')
    end
else
    close (2)
    [spettro] = PVcount(signal,Plots);
end

% ES=0; %Goodman (Sa / Se + Sm / Sut = 1) 
% ES=1; %Gerber (Sa / Se + (Sm / Sut)^2 = 1) 
% ES=2; %No Correction
ES=0;
[speceqv] = eqvspec(spettro, Sut, ES);
%[speceqv] = eqvspec(rfc, Sut, ES);

saeqv1=(sum(speceqv(:,1).*(speceqv(:,2).^(-1/Wb(2))))/sum(speceqv(:,1)))^(-Wb(2))
neqv1=sum(speceqv(:,1))
Neqv1=(saeqv1/Wb(1))^(1/Wb(2))
nN1=Neqv1/neqv1
Seqv1=Wb(1)*neqv1^(Wb(2))
nS1=Seqv1/saeqv1

saeqv2=(sum(spettro_d(:,1).*(spettro_d(:,2).^(-1/Wb(2))))/sum(spettro_d(:,1)))^(-Wb(2))
neqv2=sum(spettro_d(:,1))
Neqv2=(saeqv2/Wb(1))^(1/Wb(2))
nN2=Neqv2/neqv2
Seqv2=Wb(1)*neqv2^(Wb(2))
nS2=Seqv2/saeqv2

%Coefficiente di spettro
carico_max=max(speceqv(:,2));
carico_max_d=max(spettro_d(:,2));
Kp=(sum(speceqv(:,1).*((speceqv(:,2)/carico_max).^(-1/Wb(2))))/sum(speceqv(:,1)))
Kp_d=(sum(spettro_d(:,1).*((spettro_d(:,2)/carico_max_d).^(-1/Wb(2))))/sum(spettro_d(:,1)))
alfa=Kp^(-Wb(2))
alfa_d=Kp_d^(-Wb(2))
seqvkp=alfa*carico_max;
seqvkp_d=alfa_d*carico_max_d;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Ricostruzione pdf sperimentale
plotid=0;
[x_r, y_r]=plotta_pdf(speceqv,num,3,'r',plotid);
pdf_r(:,2)=x_r;
pdf_r(:,1)=y_r;
 
%Plottaggio pdf
figure
plot(pdf_r(:,2),pdf_r(:,1),'r','linewidth',2)
hold on
plot(pdf_d(:,2),pdf_d(:,1),'k','linewidth',2)
plot(pdf_b(:,2),pdf_b(:,1),'b','linewidth',2)
hold on
grid on
ylabel('Pdf')
xlabel('units')
title('Pdf di carico')
legend('Sperimentale','Dirlik','Bendat')

spe_r = cumula(speceqv,'r',0,100);
spe_d = cumula(spettro_d,'k',0,100);
spe_b = cumula(spettro_b,'b',0,100);
pp=axis;
axis([1 max(spe_r(:,1))*2 0 max(spe_r(:,2))*1.2])
legend('Sperimentale','Dirlik','Bendat')

Miner_D=1;
type=0;
[Dcum] = damage(speceqv, Miner_D, S, Wb, type)
Life=Miner_D/Dcum
saeqv12=((sum(speceqv(:,1))/Dcum)^Wb(2))*Wb(1)
neqv12=sum(speceqv(:,1))
Neqv12=(saeqv12/Wb(1))^(1/Wb(2))
nN12=Neqv12/neqv12
Seqv12=Wb(1)*neqv12^(Wb(2))
nS12=Seqv12/saeqv12

Miner_D=1;
type=1;
[Dcumf] = damage(spettro_d, Miner_D, S, Wb, type)
Lifef=Miner_D/Dcumf
saeqv22=((sum(spettro_d(:,1))/Dcum)^Wb(2))*Wb(1)
neqv22=sum(spettro_d(:,1))
Neqv22=(saeqv22/Wb(1))^(1/Wb(2))
nN22=Neqv22/neqv22
Seqv22=Wb(1)*neqv22^(Wb(2))
nS22=Seqv22/saeqv22

figid=100;
figure(figid)
hold on
semilogx([1 sum(speceqv(:,1))],[saeqv1 saeqv1],'r')
semilogx([1 sum(speceqv(:,1))],[saeqv12 saeqv12],'r','linewidth',2)
semilogx([1 sum(spettro_d(:,1))],[saeqv2 saeqv2],'k')
semilogx([1 sum(spettro_d(:,1))],[saeqv22 saeqv22],'k','linewidth',2)

figid=7;
figure(figid)
hold on
loglog(spe_r(:,1),spe_r(:,2),'r')
loglog(spe_d(:,1),spe_d(:,2),'k')
plot(neqv12,saeqv12,'rx','linewidth',2)
plot(neqv12,Seqv12,'ro','linewidth',2)
plot(Neqv12,saeqv12,'ro','linewidth',2)
plot(neqv22,saeqv22,'kx','linewidth',2)
plot(neqv22,Seqv22,'ko','linewidth',2)
plot(Neqv22,saeqv22,'ko','linewidth',2)


