clear all
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Definizione componente e materiale

% Albero
d=35; %(mm)
t=70; %F
r=3; %(mm) Raccordo

Sut=1000;
Sy=0.8*Sut;
Csut=0.044;
Kso=0.9;
Nse=1e6;
Kse=0.504;
Cse=0.146;
Rel=95;
Kb=1/3;

ka=4.51*Sut^-0.265;
Cka=0.06;
kb=(d/7.63)^-0.1133;
Ckb=0;
kc=1;
Ckc=0;
kd=(0.975+0.432e-3*t-0.115e-5*t^2+0.104e-8*t^3-0.595e-12*t^4);
Ckd=0.11;
a=0.025*(2070/Sut)^1.8;
q=1/(1+a/r);
Kt=1.75;
Kf=1+q*(Kt-1);
ke=1/Kf;
Cke=0.08;

K=ka*kb*kc*kd*ke;
Ck=sqrt(Cka^2+Ckb^2+Ckc^2+Ckd^2+Cke^2);

Plots=1;
[Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots);
hold on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Caricamento segnale in frequenza

load out1; %Sistema monomodale (narrow band) teorico (analisi in frequenza)
load out2; %Sistema bimodale (wide band) teorico (analisi in frequenza)

T=10000; %Durata segnale di riferimento

freq=out1(:,1);
PSDf=out1(:,2);
freq=out2(:,1);
PSDf=out2(:,2);

% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik
[Mom_ff,Momf] = statPSD(freq,PSDf);    

rms_f = sqrt(Mom_ff(1))
Np_f=sqrt(Mom_ff(5)/Mom_ff(3))
N0p_f=sqrt(Mom_ff(3)/Mom_ff(1))
gamma_f=Mom_ff(3)/sqrt(Mom_ff(1)*Mom_ff(5))

% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik e bendat
deltasigma=10;
[pdf_d,Mom_d] = dirlik(freq,PSDf,deltasigma);    
[pdf_b,Mom_b] = rayleigh(freq,PSDf,deltasigma);    
N_d=deltasigma/2*sqrt(Mom_d(5)/Mom_d(3));
N_b=deltasigma/2*sqrt(Mom_b(5)/Mom_b(3));
spettro_d=[pdf_d(:,1)*T*N_d pdf_d(:,2)];
spettro_b=[pdf_b(:,1)*T*N_b pdf_b(:,2)];
rms_d = sqrt(Mom_d(1));
rms_b = sqrt(Mom_b(1));


saeqv2=(sum(spettro_d(:,1).*(spettro_d(:,2).^(-1/Wb(2))))/sum(spettro_d(:,1)))^(-Wb(2))
neqv2=sum(spettro_d(:,1))
Neqv2=(saeqv2/Wb(1))^(1/Wb(2))
nN2=Neqv2/neqv2
Seqv2=Wb(1)*neqv2^(Wb(2))
nS2=Seqv2/saeqv2

%Coefficiente di spettro
carico_max_d=max(spettro_d(:,2));
Kp_d=(sum(spettro_d(:,1).*((spettro_d(:,2)/carico_max_d).^(-1/Wb(2))))/sum(spettro_d(:,1)))
alfa_d=Kp_d^(-Wb(2))
seqvkp_d=alfa_d*carico_max_d;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Plottaggio pdf
figure
plot(pdf_d(:,2),pdf_d(:,1),'k','linewidth',2)
hold on
plot(pdf_b(:,2),pdf_b(:,1),'b','linewidth',2)
hold on
grid on
ylabel('Pdf')
xlabel('units')
title('Pdf di carico')
legend('Dirlik','Bendat')

spe_d = cumula(spettro_d,'k',0,100);
spe_b = cumula(spettro_b,'b',0,100);
pp=axis;
axis([1 max(spe_d(:,1))*2 0 max(spe_d(:,2))*1.2])
legend('Dirlik','Bendat')

Miner_D=1;
type=1;
[Dcumf] = damage(spettro_d, Miner_D, S, Wb, type)
Lifef=Miner_D/Dcumf
saeqv22=((sum(spettro_d(:,1))/Dcumf)^Wb(2))*Wb(1)
neqv22=sum(spettro_d(:,1))
Neqv22=(saeqv22/Wb(1))^(1/Wb(2))
nN22=Neqv22/neqv22
Seqv22=Wb(1)*neqv22^(Wb(2))
nS22=Seqv22/saeqv22

figid=100;
figure(figid)
hold on
semilogx([1 sum(spettro_d(:,1))],[saeqv2 saeqv2],'k')
semilogx([1 sum(spettro_d(:,1))],[saeqv22 saeqv22],'k','linewidth',2)

figid=1;
figure(figid)
hold on
loglog(spe_d(:,1),spe_d(:,2),'k')
plot(neqv22,saeqv22,'kx','linewidth',2)
plot(neqv22,Seqv22,'ko','linewidth',2)
plot(Neqv22,saeqv22,'ko','linewidth',2)


