function [Dcum,maxD_tmp] = damage(speceqv, Miner_D, S, W, type)
%
% [Dcum,maxD_tmp] = damage(speceqv, Miner_D, S, W, type)
% INPUT
% speceqv:	Spettro alterno equivalente
% Miner_D:	Limite di danneggiamento di Miner
% S:        [Sut1 S0 Se Slim] 
%	        Sut1:	Sut*Krso;
%     	    S0:    sigma limite a 10^3 cicli
%           Se:  	sigma limite a Nse cicli (cicli a vita indefinita)
%	        Slim:	sigma limite a Nlim cicli 
% W:        [a1 b1 a2 b2]' con a e b coefficienti tali che sigma= a*N^b (curva di  
%           Wohler); a2 e b2 sono i coefficienti dopo Nse cicli; 
% type:	    Tipo di analisi: 0 time domain, 1 frequency domain
% OUTPUT
% Dcum:     Damage
%
%   F.Cianetti & A. Grilli 
%   Copyright 2004-2010 COSMAC 
%   $Revision: 1.0 $  $Date: 01/09/04 


MSG1='!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!';
MSG2='!  Be careful: Material Static Failure  !';
MSG3='!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!';

S0=S(2);
Se=S(3);
a1=W(1);
a2=W(3);
b1=W(2);
b2=W(4);



[nr,nc]=size(speceqv);

D_tmp=zeros(nr,1);
for i=1:nr,   
   if speceqv(i,2) >= S0,
       D_tmp(i)=Miner_D;
   else
       if speceqv(i,2) > Se,
           D(i)=1/((speceqv(i,2)/a1)^(1 / b1))*speceqv(i,1);
       else
           if b2==0,
               D(i)=0;
           else
               D(i)=1/((speceqv(i,2)/a2)^(1 / b2))*speceqv(i,1);
           end
       end
   end
end

Dcum=sum(D);
maxD_tmp=max(D_tmp);
if type == 0,
    if max(D_tmp)==Miner_D,
        disp([MSG1; MSG2; MSG3])
    end
    
end
