function [Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots)


% Sut    material strenght
% Csut   coefficient of variation of Sut
% Nse    endurance limit cycles number (cycle)
% Kse    material fatigue ratio at Nse cycles (Bending)
% Kso    material fatigue ratio at N=10^3 cycles
% K      endurance limit modifying factor 
% Kb     slope coefficient for stress life after Nse cycles 
% Rel    reliability (%)
% Cse    coefficient of variation of Kse coefficient
% Ck     coefficient of variation of K coefficient
% Plots  plot parameter

N0=1.00000E+03;  	                    %Cycles	
Nlim=1.00000E+010;  	                %Cycles	

R=norminv(Rel/100,0,1);
C=sqrt(Cse^2+Ck^2);
Cso=sqrt(Csut^2);
Krso=1-Cso*R;  %modifying factor (reliability) at N=10^3 cycles
Krse=1-C*R;    %modifying factor (reliability) at Nse cycles

S0=Kso*Krso*Sut;
Se=Kse*K*Krse*Sut;	                     
Sut1=Sut*Krso;
b1=log10(Se/S0)/log10(Nse/N0);
a1=(S0)/N0^b1;
b2=Kb*b1;
a2=10^(log10(Se)-b2*log10(Nse));	         

if b2==0,
    Slim=Se;
else
    Slim=a2*Nlim^b2;
end

Wb=[a1 b1 a2 b2]';
N=[1 N0 Nse Nlim]';
S=[Sut1 S0 Se Slim]';

if Plots==1,

S0=Kso*Sut;                        
Se=Kse*K*Sut;	                     
Sut1=Sut;
b1=log10(Se/S0)/log10(Nse/N0);
a1=(S0)/N0^b1;
b2=Kb*b1;
a2=10^(log10(Se)-b2*log10(Nse));	         
if b2==0,
    Slim=Se;
else
    Slim=a2*Nlim^b2;
end

N1=[1 N0 Nse Nlim]';
S1=[Sut1 S0 Se Slim]';

figure
p=loglog(N(2:4,1),S(2:4,1),'b');
set(p,'Linewidth',2);
hold on
p=loglog(N(1:2,1),S(1:2,1),'b--');
set(p,'Linewidth',1);
p=loglog(N1(2:4,1),S1(2:4,1),'r');
set(p,'Linewidth',2);
p=loglog(N1(1:2,1),S1(1:2,1),'r--');
set(p,'Linewidth',1);
grid on
title('Wohler Curve (bending)')
xlabel('Cycles log(N)')
ylabel('Stress amplitude log(Stress unit)')
axis([N(1) N(4) S(4) S1(1)])
hold off
end




