function matrix_plot(matrix,range,scale,n_color,line)
%function matrix_plot(matrix)
%%matrix plot of matrix element with box objects
%%(bar3 seems not use colorbar!!!)
%%created on 30-sept-2007
%%Michele Martini

% matrix: matrice mxn mean-range oppure min-max
% range : vettore 2x2 con per ogni riga i valori di min e max rispettivamente dell'asse x e y 
% scale: determina la dimensione di base delle colonne
% n_color: numero di colori della colorbar
% line: se pari ad 1 disegna la discretizzazione dei livelli di
%            ciascuna colonna, se pari a 0 o risulta mancante nulla
if nargin < 3
    scale=0.1;
end
if nargin < 4
     n_color=32;
end
if nargin < 5
     line=0;
end

if line==0
    line_plot='none';
else
    line_plot=0;
end
if scale>=1
    error ('scale deve essere pi piccolo di 1')
end
M=max(max(matrix));
m=min(min(matrix));
color_scale=m:(M-m)/(n_color-1):M;

if (nargin<2 || isempty(range))
    Y=[scale scale 1-scale 1-scale scale];
    X=[scale 1-scale 1-scale scale scale];

    y=ones(n_color+1,1)*Y; 
    x=ones(n_color+1,1)*X;

    y_1=[scale 1-scale];
    x_1=[scale 1-scale];
    
    x_unit_axis=0:1:size(matrix,1);
    y_unit_axis=0:1:size(matrix,2);
else

x_unit_axis = range(1,1):(range(1,2)-range(1,1))/(size(matrix,1)-1):range(1,2);
y_unit_axis = range(2,1):(range(2,2)-range(2,1))/(size(matrix,2)-1):range(2,2);

Y=[-0.5+scale -0.5+scale 0.5-scale 0.5-scale -0.5+scale]*(range(1,2)-range(1,1))/(size(matrix,2)-1);
X=[-0.5+scale 0.5-scale 0.5-scale -0.5+scale -0.5+scale]*(range(2,2)-range(2,1))/(size(matrix,1)-1);

y=ones(n_color+1,1)*Y;
x=ones(n_color+1,1)*X;

y_1=[-0.5+scale 0.5-scale]*(range(1,2)-range(1,1))/(size(matrix,2)-1);
x_1=[-0.5+scale 0.5-scale]*(range(2,2)-range(2,1))/(size(matrix,1)-1);
end

for i=1:size(matrix,1)
    x1=x+x_unit_axis(i)*ones(size(x));
    x1_1=x_1+x_unit_axis(i)*ones(size(x_1));
    for j=1:size(matrix,2)
        a=matrix(i,j);
        y1=y+y_unit_axis(j)*ones(size(y));
        y1_1=y_1+y_unit_axis(j)*ones(size(y_1));
        z_1=a*ones(2,2);
        level=find(color_scale >= a);
        k_end=level(1);
        clear level;
        z=zeros(k_end+1,5);
        for k=0:k_end
            z(k+1,:)=ones(1,5)*a/(k_end)*k;
        end  
        surf(x1_1,y1_1,z_1,'LineStyle','none')
        hold on
        if strcmp(line_plot,'none')
            surf(x1(1:k_end+1,:),y1(1:k_end+1,:),z,z,'LineStyle','none')
        else
            surf(x1(1:k_end+1,:),y1(1:k_end+1,:),z,z)
        end
        clear k_end
        clear z
    end
end
colorbar
if ~(nargin<2 || isempty(range))
    fx=(range(1,2)-range(1,1))/(size(matrix,1)-1);
    fy=(range(2,2)-range(2,1))/(size(matrix,2)-1);
axis([range(1,1)-fx range(1,2)+fx range(2,1)-fy range(2,2)+fy 0 inf])
end
hold off