%%
clear all
close all
clc

load STRESS.mat

time=t(2:end);
Sx=tensor(:,1);
Sy=tensor(:,2);
Sxy=tensor(:,3);

%Comparazione tempo frequenza
[Ax,Bx]=spectrum(Sx,fft_point,fft_point/4,hanning(fft_point));
[Ay,By]=spectrum(Sy,fft_point,fft_point/4,hanning(fft_point));
[Axy,Bxy]=spectrum(Sxy,fft_point,fft_point/4,hanning(fft_point));

figure(4)
plot(time,Sx,'b')
hold on
grid on
xlabel('time (s)')
ylabel('stress (units)')
plot(time,Sy,'r')
plot(time,Sxy,'g')

figure(5)
loglog(freq,squeeze(PSDf(1,1,:)),'b','LineWidth',2)
hold on
loglog(freq,squeeze(PSDf(2,2,:)),'r','LineWidth',2)
loglog(freq,squeeze(PSDf(3,3,:)),'g','LineWidth',2)
title('PSD f vs PSD t')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
loglog(Bx(:,1)*maxfreq,Ax(:,1)/maxfreq,'b','LineWidth',1)
loglog(By(:,1)*maxfreq,Ay(:,1)/maxfreq,'r','LineWidth',1)
loglog(Bxy(:,1)*maxfreq,Axy(:,1)/maxfreq,'g','LineWidth',1)


% Sintesi dello stato di tensione equivalente nel tempo
[svm, ae, phi] = multiaxiality(time, tensor);
%EQVMt=eqvmt(tensor,time);

% Segnale temporale equivalente
signal=[time svm];

% Analisi in frequenza (PSD) del segnale temporale
[A1,B1]=spectrum(signal(:,2),fft_point,fft_point/4,hanning(fft_point));
freqout=B1(:,1)*maxfreq;
PSDout=A1(:,1)/maxfreq;

% Sintesi dello stato di tensione equivalente in frequenza
SVM=eqvm(PSDf,freq);


figure(13)
plot(time,svm,'r','LineWidth',0.5)
hold on
title('TH OUTPUT')
xlabel('TIME (s)')
ylabel('Signed von Mises (unit)')
grid on

figure(14)
loglog(B1(:,1)*maxfreq,A1(:,1)/maxfreq,'r','linewidth',2)
hold on
title('PSD OUTPUT')
xlabel('FREQ log(Hz)')
ylabel('PSD log(unit^2/Hz)')
grid on
loglog(freq,SVM,'b','linewidth',2)

% Estrazione della funzione di auto-correlazione
[c_ww,lags] = xcorr(svm,'coeff');

figure(15)
%stem(lags,c_ww)
plot(lags,c_ww)
hold on
grid on
ylabel('autocorrelation function')
xlabel('units')
axis([-2e3 2e3 -1.2 1.2])

% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik
[Mom_ff,Momf] = statPSD(freq,SVM);    

rms_f = sqrt(Mom_ff(1))
Np_f=sqrt(Mom_ff(5)/Mom_ff(3))
N0p_f=sqrt(Mom_ff(3)/Mom_ff(1))
gamma_f=Mom_ff(3)/sqrt(Mom_ff(1)*Mom_ff(5))

% Estrazione dello spettro dei cicli dell'unit di tempo e dei momenti spettrali mediante dirlik e bendat
deltasigma=10;
[pdf_d,Mom_d] = dirlik(freq,SVM,deltasigma);    
[pdf_b,Mom_b] = rayleigh(freq,SVM,deltasigma);    
N_d=deltasigma/2*sqrt(Mom_d(5)/Mom_d(3));
N_b=deltasigma/2*sqrt(Mom_b(5)/Mom_b(3));
spettro_d=[pdf_d(:,1)*T*N_d pdf_d(:,2)];
spettro_b=[pdf_b(:,1)*T*N_b pdf_b(:,2)];
rms_d = sqrt(Mom_d(1));
rms_b = sqrt(Mom_b(1));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Definizione componente e materiale

% Albero
d=35; %(mm)
t=70; %F
r=3; %(mm) Raccordo

Sut=1000;
Sy=0.8*Sut;
Csut=0.044;
Kso=0.9;
Nse=1e6;
Kse=0.504;
Cse=0.146;
Rel=95;
Kb=1/3;

ka=4.51*Sut^-0.265;
Cka=0.06;
kb=(d/7.63)^-0.1133;
Ckb=0;
kc=1;
Ckc=0;
kd=(0.975+0.432e-3*t-0.115e-5*t^2+0.104e-8*t^3-0.595e-12*t^4);
Ckd=0.11;
a=0.025*(2070/Sut)^1.8;
q=1/(1+a/r);
Kt=1.75;
Kf=1+q*(Kt-1);
ke=1/Kf;
Cke=0.08;

K=ka*kb*kc*kd*ke;
Ck=sqrt(Cka^2+Ckb^2+Ckc^2+Ckd^2+Cke^2);

Plots=1;
[Wb,N,S] = material(Sut, Csut, Nse, Kse, Kso, K, Kb, Rel, Cse, Ck, Plots);
hold on

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Estrazione dello spettro dei cicli mediante conteggio rainflow nel dominio
%del tempo

num=50;
% count=1; %Rainflow 
% count=2; %Peak-Valley 
count=1;
if count==1
    % P3D=1;  %RainFlow Matrix plot 3dimensional
    % P3D=0;  %RainFlow Matrix plot 2dimensional
    % RES=0; %No Residuals 
    % RES=1; %Residuals (Cloormann/Seeger) 
    P3D=0;
    RES=1;
    fil=0;
    [tp,rfc,spettro,res] = conteggio(signal,fil,num,RES,P3D,Plots);
    % spettro=rfc;

    figure
    plot(signal(:,1),signal(:,2),'b')
    hold on
    grid on
    xlabel('time (s)')
    ylabel('signed von Mises stress (stress units)')
    plot(tp(:,1),tp(:,2),'k*')
    plot(tp(:,1),tp(:,2),'ro')

    if RES==0
        figure
        plot(res(:,1),res(:,2))
        hold on
        grid on
        xlabel('time (s)')
        ylabel('stress (units)')
        title('Residuals')
    end
    % ES=0; %Goodman (Sa / Se + Sm / Sut = 1) 
    % ES=1; %Gerber (Sa / Se + (Sm / Sut)^2 = 1) 
    % ES=2; %No Correction
    ES=0;
    [speceqv] = eqvspec(spettro, Sut, ES);
    N_r=sum(spettro(:,1));
else
    [speceqv] = PVcount(signal);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

saeqv1=(sum(speceqv(:,1).*(speceqv(:,2).^(-1/Wb(2))))/sum(speceqv(:,1)))^(-Wb(2))
neqv1=sum(speceqv(:,1))
Neqv1=(saeqv1/Wb(1))^(1/Wb(2))
nN1=Neqv1/neqv1
Seqv1=Wb(1)*neqv1^(Wb(2))
nS1=Seqv1/saeqv1

saeqv2=(sum(spettro_d(:,1).*(spettro_d(:,2).^(-1/Wb(2))))/sum(spettro_d(:,1)))^(-Wb(2))
neqv2=sum(spettro_d(:,1))
Neqv2=(saeqv2/Wb(1))^(1/Wb(2))
nN2=Neqv2/neqv2
Seqv2=Wb(1)*neqv2^(Wb(2))
nS2=Seqv2/saeqv2

%Coefficiente di spettro
carico_max=max(speceqv(:,2));
carico_max_d=max(spettro_d(:,2));
Kp=(sum(speceqv(:,1).*((speceqv(:,2)/carico_max).^(-1/Wb(2))))/sum(speceqv(:,1)))
Kp_d=(sum(spettro_d(:,1).*((spettro_d(:,2)/carico_max_d).^(-1/Wb(2))))/sum(spettro_d(:,1)))
alfa=Kp^(-Wb(2))
alfa_d=Kp_d^(-Wb(2))
seqvkp=alfa*carico_max;
seqvkp_d=alfa_d*carico_max_d;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Ricostruzione pdf sperimentale
%num=20;
plotid=0;
[x_r, y_r]=plotta_pdf(speceqv,num,3,'r',plotid);
pdf_r(:,2)=x_r;
pdf_r(:,1)=y_r;
 
%Plottaggio pdf
figure
plot(pdf_r(:,2),pdf_r(:,1),'r','linewidth',2)
hold on
plot(pdf_d(:,2),pdf_d(:,1),'k','linewidth',2)
plot(pdf_b(:,2),pdf_b(:,1),'b','linewidth',2)
hold on
grid on
ylabel('Pdf')
xlabel('units')
title('Pdf di carico')
legend('Sperimentale','Dirlik','Bendat')

spe_d = cumula(spettro_d,'k',0,100);
spe_b = cumula(spettro_b,'b',0,100);
spe_r = cumula(speceqv,'r',0,100);
pp=axis;
axis([1 max(spe_r(:,1))*2 0 max(spe_r(:,2))*1.2])
legend('Dirlik','Bendat','Sperimentale')

Miner_D=1;
type=0;
[Dcum] = damage(speceqv, Miner_D, S, Wb, type)
Life=Miner_D/Dcum
saeqv12=((sum(speceqv(:,1))/Dcum)^Wb(2))*Wb(1)
neqv12=sum(speceqv(:,1))
Neqv12=(saeqv12/Wb(1))^(1/Wb(2))
nN12=Neqv12/neqv12
Seqv12=Wb(1)*neqv12^(Wb(2))
nS12=Seqv12/saeqv12

Miner_D=1;
type=1;
[Dcumf] = damage(spettro_d, Miner_D, S, Wb, type)
Lifef=Miner_D/Dcumf
saeqv22=((sum(spettro_d(:,1))/Dcum)^Wb(2))*Wb(1)
neqv22=sum(spettro_d(:,1))
Neqv22=(saeqv22/Wb(1))^(1/Wb(2))
nN22=Neqv22/neqv22
Seqv22=Wb(1)*neqv22^(Wb(2))
nS22=Seqv22/saeqv22

figid=100;
figure(figid)
hold on
semilogx([1 sum(speceqv(:,1))],[saeqv1 saeqv1],'r')
semilogx([1 sum(speceqv(:,1))],[saeqv12 saeqv12],'r','linewidth',2)
semilogx([1 sum(spettro_d(:,1))],[saeqv2 saeqv2],'k')
semilogx([1 sum(spettro_d(:,1))],[saeqv22 saeqv22],'k','linewidth',2)

figid=10;
figure(figid)
hold on
loglog(spe_r(:,1),spe_r(:,2),'r')
loglog(spe_d(:,1),spe_d(:,2),'k')
plot(neqv12,saeqv12,'rx','linewidth',2)
plot(neqv12,Seqv12,'ro','linewidth',2)
plot(Neqv12,saeqv12,'ro','linewidth',2)
plot(neqv22,saeqv22,'kx','linewidth',2)
plot(neqv22,Seqv22,'ko','linewidth',2)
plot(Neqv22,saeqv22,'ko','linewidth',2)


