function [svm, ae, phi] = multiaxiality(time, tensor)

% i.e.   [svm, ae, phi] = multiaxiality(time, tensor)

%time          
%tensor         stress tensor with three columns: Sx Sy Sxy

Sx=tensor(:,1);
Sy=tensor(:,2);
Sxy=tensor(:,3);

rris=max(size(tensor));

TS1=[Sx(1) Sxy(1);
    Sxy(1) Sy(1)];

[VPRIN1,OSPRIN1,FLAG]=eigs(TS1);    
ANGPRIN=acos(VPRIN1)*180/pi;
ANGREF=ANGPRIN(1,1);

SPRIN=zeros(1,2);
for k=1:rris,
   TS=[Sx(k) Sxy(k);
       Sxy(k) Sy(k)];
   [VPRIN,OSPRIN,FLAG]=eigs(TS);
   SPRIN(k,:)=diag(OSPRIN)';
   angprin=acos(VPRIN)*180/pi;
   ang(k,:)=angprin(:,1)';
end

S1=SPRIN(:,1);
S2=SPRIN(:,2);

ae=S2./S1;
phi=ang(:,1)-ANGREF;

for k=1:rris,
   [v,o]=sort(abs(SPRIN(k,:)));
   SPRIN1=(SPRIN(k,o(2)));
   SPRIN2=(SPRIN(k,o(1)));
   VMN(k)=0.7071*((SPRIN(k,1)-SPRIN(k,2))^2+(SPRIN(k,2))^2+(-SPRIN(k,1))^2)^0.5;
%   VMN(k)=0.7071*((Sx(k)-Sy(k))^2+(Sy(k))^2+(-Sx(k))^2+6*(Sxy(k)^2))^0.5; 
end
svm=(SPRIN(:,1)./abs(SPRIN(:,1))).*VMN';

figure
plot(time,Sx,'r')
hold on
grid on
plot(time,Sy,'b')
plot(time,Sxy,'k')
xlabel('time (s)')
ylabel('stress tensor component Sx (r), Sy (b), Sxy (k) (stress units)')

figure
plot(time,S1,'r')
hold on
grid on
plot(time,S2,'b')
xlabel('time (s)')
ylabel('principal stress S1 (r), S2 (b) (stress units)')

figure
plot(time,phi)
grid on
%axis([0 time(end) (min(phi)) (max(phi)) ])
xlabel('time (s)')
ylabel('principal stress angle (deg)')

figure
plot(time,ae)
grid on
axis([0 time(end) min(ae) max(ae)])
xlabel('time (s)')
ylabel('elastic biaxiality ratio (none)')

figure
plot(ae,S1,'*')
grid on
axis([min(ae) max(ae) -max(S1) max(S1)])
xlabel('elastic biaxiality ratio (none)')
ylabel('max principal stress (stress units)')

figure
plot(phi,S1,'*')
grid on
%axis([(min(phi)) (max(phi)) -max(S1) max(S1) ])
xlabel('principal stress angle (deg)')
ylabel('max principal stress (stress units)')

figure
plot(time,VMN,'r')
hold on
grid on
plot(time,svm,'b')
plot(time,VMN,'r.')
xlabel('time (s)')
ylabel('von Mises (r) and signed von Mises (b) stress (stress units)')


