% MATLAB-code to analyze multiaxial fatigue
% if the stresses are in-phase and the principal
% stress directions are fixed.
% Use on your own risc
% AE 971126
% Edited 981202-anek

clear all
% Material data
SeS=160e6
SeC=208e6
SeDV=104e6
cS=0.69
cC=0.9
cDV=.45

a=zeros(3,3);
j=0
for i=0:0.01:2*pi
  j=j+1
  % Stress tensor
  % s11 s12 s13
  % s12 s22 s23
  % s13 s23 s33
  s11=100e6.*sin(i);
  s12=0;
  s13=0;
  s22=120e6.*sin(i);
  s23=0;
  s33=0;

  % Hydrostatic stress
  sh(j)=(s11+s22+s33)/3;

  % Create deviatoric stress tensor
  % s11d s12d s13d
  % s12d s22d s23d
  % s13d s23d s33d
  s11d(j)=s11-sh(j);
  s12d(j)=s12;
  s13d(j)=s13;
  s22d(j)=s22-sh(j);
  s23d(j)=s23;
  s33d(j)=s33-sh(j);
end

% Mid and max-value of hydrostatic stress
shmid=median(sh);
shmax=max(sh);

% Mid value of deviatoric stress tensor
s11dm=median(s11d)
s12dm=median(s12d)
s13dm=median(s13d)
s22dm=median(s22d)
s23dm=median(s23d)
s33dm=median(s33d)

% Deviation of the deviatoric stress tensor
s11da=s11d-s11dm;
s12da=s12d-s12dm;
s13da=s13d-s13dm;
s22da=s22d-s22dm;
s23da=s23d-s23dm;
s33da=s33d-s33dm;

% Principal values of the deviation of the deviatoric
% stress tensor
for i=1:j
  s=[s11da(i) s12da(i) s13da(i);...
     s12da(i) s22da(i) s23da(i);...
     s13da(i) s23da(i) s33da(i)];
 
  sp=sort(eig(s));
  % Tresca "shear stress amplitude"
  tresca(i)=(sp(3)-sp(1))/2;
  % Dang van stress
  dv(i)=tresca(i)+cDV*sh(i);

  % Crossland and Sines Criteria
  t=0;
  for k=1:3
    for l=1:3
      t=t+s(k,l)*s(k,l);
    end
  end
  tdev(i)=sqrt(3*t/2);
  seq1(i)=tdev(i)+cS*shmid;
  seq2(i)=tdev(i)+cC*shmax;
end

x=[1:j]./j;
 
figure(1) 				% Dang Van criterion
plot(x,dv,'-',x,tresca,'-.',x,sh,'--')
grid
legend('Dang Van equivalent stress','Tresca amplitude','Hydrostatic stress')
title('Dang Van equivalent stress')
ylabel('Stress')
xlabel('time/(2*pi)')
% Maximum Dang Van equivalent stress
MaxDv=max(dv)
MaxTrescaAmp=max(tresca)
SFdv=SeDV/MaxDv

figure(2) 				% Sines criterion
plot(x,seq1,'-',x,tdev,'-.')
grid
legend('Sines equivalent stress','Sqrt(3/2*Sij,a*Sij,a)')
title('Sines equivalent stress')
ylabel('Stress')
xlabel('time/(2*pi)')
% Maximum Sines equivalent stress
MaxDevStress=max(tdev)
MaxSines=max(seq1)
SFs=SeS/MaxSines

figure(3) 				% Crossland criterion
plot(x,seq2,'-',x,tdev,'-.')
grid
legend('Crossland equivalent stress','Sqrt(3/2*Sij,a*Sij,a)')
title('Crossland equivalent stress')
ylabel('Stress')
xlabel('time/(2*pi)')
% Maximum Crossland equivalent stress
MaxCrossland=max(seq2)
SFc=SeC/MaxCrossland
