% Made by: Anders Ekberg, Dept. of Solid Mechanics, Chalmers 1997-11-04
% Can be used freely at your own risc.
% 
% Plot of Mohr's circle of stress in two dimensions. 
% Equations in Gere/Timoshenko-"Mechanics of Materials" 3rd SI-edition
% are employed

clear all
 format short

 % Define values for original coordinate system
 % (i.e. for theta=0)
 sx=input('SigmaX: ');
 sy=input('SigmaY: ');
 tao=input('Shear stress: ');
 
 % Define theta
 theta=0:pi/90:2*pi;
 
 % Calculate stresses s and t as a function of theta
 % according to Eq.(6-4a,b) 
 % Note that sy is obtained as
 % sx with theta=theta+(Pi/2) [rad]
 s=(sx+sy)/2+(sx-sy)*cos(2*theta)/2+tao*sin(2*theta);
 t=-1*(sx-sy)*sin(2*theta)/2+tao*cos(2*theta);

 % Calculate principal stresses (ekv. 6-13)
 s1=(sx+sy)/2+sqrt(((sx-sy)/2)^2+tao^2)
 s2=(sx+sy)/2-sqrt(((sx-sy)/2)^2+tao^2)

 % Calculate the angle to these (ekv. 6-9)
 phi=(atan(2*tao/(sx-sy)))/2*360/2/pi
 
 % Largest and smallest shear stresse (ekv. 6-21)
 tmax=(s1-s2)/2

 % Calculate mean normal stress (normal stress corresponding to
 % tmax)
 smed=(s1+s2)/2
 
 % Create coordinate axes
 % Scale parameter
 skal=0.2*(s1-s2);
 x=[s2-skal  s1+skal];
 y=[-tmax-skal  tmax+skal];
 noll=[0  0];
 
 hold on
 plot(s,t,'-')
 % Plot coordinate axes
 plot(x,noll,'--')
 plot(noll,y,'--')
 % Plot indata
 plot(sx,tao,'x')
 plot(sy,tao,'x')
 % Plot principal stresses (NOTE! tao=0 for these)
 plot(s1,0,'o')
 plot(s1,0,'x')
 plot(s2,0,'o')
 plot(s2,0,'x')
 % Plot largest/smallest shear stress
 plot(smed,tmax,'o')
 plot(smed,-tmax,'o')
 axis([s2-skal, s1+skal, -tmax-skal, tmax+skal])
 axis('square')
 title(['Mohr''s circle - sx= ',num2str(sx),' sy=',num2str(sy),' tao=',num2str(tao),' '], 'Fontname','Helvetica','Fontsize',14)
 text(s2-0.9*skal,tmax+0.9*skal,['Principal stresses: S1= ',num2str(s1),' S2= ',num2str(s2)], 'Fontname','Times','Fontsize',10)
 text(s2-0.9*skal,tmax+0.5*skal,['Max and min shear stress= +-',num2str(tmax)], 'Fontname','Times','Fontsize',10)
 text(s2-0.9*skal,tmax+0.1*skal,['Mean value of normal stress= ',num2str(smed)], 'Fontname','Times','Fontsize',10)
 text(s2-0.9*skal,tmax-0.3*skal,['Angle to plane of principal stress=',num2str(phi),' +n*90 grader'], 'Fontname','Times','Fontsize',10)
 hold off


